from typing import List, Dict, Optional, Tuple

__all__ = ['get_fistword_exprs']

_CLICHE_EXPR_DICT_KEYLEN = 6

# Source: http://diccionariodelcliche.umh.es/
_CLICHE_EXPR: Tuple[List[str], ...] = (
    ["a", "base", "de", "bien"],
    ["a", "bocajarro"],
    ["a", "brazo", "partido"],
    ["a", "buenas", "horas"],
    ["a", "caballo", "entre"],
    ["a", "caer", "de", "un", "burro"],
    ["a", "caldo"],
    ["a", "calzón", "quitado"],
    ["a", "capa", "y", "espada"],
    ["a", "cara", "de", "perro"],
    ["a", "cara", "o", "cruz"],
    ["a", "ciegas"],
    ["a", "ciencia", "cierta"],
    ["a", "cuentagotas"],
    ["a", "cuerpo", "de", "rey"],
    ["a", "cámara", "lenta"],
    ["a", "decir", "verdad"],
    ["a", "degüello"],
    ["a", "disposición", "judicial"],
    ["a", "dos", "velas"],
    ["a", "duras", "penas"],
    ["a", "escote"],
    ["a", "estas", "alturas", "de", "la", "película"],
    ["a", "estas", "alturas"],
    ["a", "fin", "de", "cuentas"],
    ["a", "freír", "espárrafos"],
    ["a", "freír", "espárragos"],
    ["a", "gloria", "bendita"],
    ["a", "huevo"],
    ["a", "la", "altura", "de", "las", "circunstancias"],
    ["a", "la", "buchaca"],
    ["a", "la", "buena", "de", "dios"],
    ["a", "la", "chita", "callando"],
    ["a", "la", "porra"],
    ["a", "la", "tercera", "va", "la", "vencida"],
    ["a", "la", "virulé"],
    ["a", "la", "voz", "de", "ya"],
    ["a", "la", "vuelta", "de", "la", "esquina"],
    ["a", "las", "cosas", "por", "su", "nombre"],
    ["a", "las", "duras", "y", "a", "las", "maduras"],
    ["a", "las", "mil", "maravillas"],
    ["a", "las", "primeras", "de", "cambio"],
    ["a", "lo", "bestia"],
    ["a", "lo", "hecho", "pecho"],
    ["a", "lo", "largo", "y", "ancho", "del", "país"],
    ["a", "lo", "loco"],
    ["a", "lo", "tonto", "a", "lo", "tonto"],
    ["a", "los", "cuatro", "vientos"],
    ["a", "los", "cuatros", "vientos"],
    ["a", "mandíbula", "batiente"],
    ["a", "mansalva"],
    ["a", "marchamartillo"],
    ["a", "marchas", "forzadas"],
    ["a", "matacaballo"],
    ["a", "medias", "tintas"],
    ["a", "medio", "gas"],
    ["a", "mesa", "puesta"],
    ["a", "más", "no", "poder"],
    ["a", "mí", "no", "me", "la", "juegas"],
    ["a", "mí", "no", "me", "tose", "nadie"],
    ["a", "mí", "plin"],
    ["a", "mí", "que", "me", "registren"],
    ["a", "nadie", "le", "amarga", "un", "dulce"],
    ["a", "nivel", "de"],
    ["a", "no", "más", "tardar"],
    ["a", "ojo", "de", "buen", "cubero"],
    ["a", "otra", "cosa", "mariposa"],
    ["a", "otro", "perro", "con", "ese", "hueso"],
    ["a", "palo", "seco"],
    ["a", "pan", "y", "agua"],
    ["a", "parir"],
    ["a", "partir", "un", "piñón"],
    ["a", "paso", "de", "tortuga"],
    ["a", "pasos", "agigantados"],
    ["a", "patadas"],
    ["a", "pedir", "de", "boca"],
    ["a", "pelo"],
    ["a", "pique"],
    ["a", "piñón", "fijo"],
    ["a", "por", "ello"],
    ["a", "por", "todas"],
    ["a", "por", "uvas"],
    ["a", "porrillo"],
    ["a", "posta"],
    ["a", "prueba", "de", "bombas"],
    ["a", "punta", "pala"],
    ["a", "punto", "de", "caramelo"],
    ["a", "quemarropa"],
    ["a", "rajatabla"],
    ["a", "ras", "de", "tierra"],
    ["a", "rebufo", "de"],
    ["a", "regañadientes"],
    ["a", "renglón", "seguido"],
    ["a", "sabiendas"],
    ["a", "saco", "paco"],
    ["a", "saco"],
    ["a", "salto", "de", "mata"],
    ["a", "sangre", "fría"],
    ["a", "santo", "de", "qué"],
    ["a", "simple", "vista"],
    ["a", "su", "aire"],
    ["a", "su", "bola"],
    ["a", "sus", "espaldas"],
    ["a", "tiro", "de", "piedra"],
    ["a", "tiro", "hecho"],
    ["a", "toda", "caña"],
    ["a", "toda", "costa"],
    ["a", "toda", "máquina"],
    ["a", "toda", "pastilla"],
    ["a", "toda", "vela"],
    ["a", "toda", "velocidad"],
    ["a", "todas", "luces"],
    ["a", "todo", "gas"],
    ["a", "todo", "trapo"],
    ["a", "todo", "tren"],
    ["a", "tomar", "viento"],
    ["a", "toro", "pasado"],
    ["a", "tumba", "abierta"],
    ["a", "tutiplén"],
    ["a", "uña", "de", "caballo"],
    ["a", "voleo"],
    ["a", "vuelapluma"],
    ["abandonar", "el", "barco"],
    ["abr", "brecha"],
    ["abr*", "camino"],
    ["abr*", "de", "par", "en", "par"],
    ["abr*", "la", "caja", "de", "los", "truenos"],
    ["abr*", "la", "caja", "de", "pandora"],
    ["abr*", "la", "mente"],
    ["abr*", "la", "veda"],
    ["abr*", "los", "ojos"],
    ["abr*", "un", "melón"],
    ["abr*", "una", "puerta", "a", "algo"],
    ["abr*", "una", "ventana", "a", "algo"],
    ["abrigar", "esperanzas"],
    ["abrumado", "por", "los", "acontecimientos"],
    ["aburr*", "a", "las", "ovejas"],
    ["aburr*", "como", "una", "ostra"],
    ["aburr*", "hasta", "las", "piedras"],
    ["acab*", "como", "el", "rosario", "de", "la", "aurora"],
    ["acabar*", "el", "chollo"],
    ["acaric*", "un", "plan"],
    ["acaric*", "una", "idea"],
    ["accidente", "fortuito"],
    ["acerca*", "los", "nubarrones"],
    ["achicar", "aguas"],
    ["achicharrar*", "de", "calor"],
    ["acompañ*", "en", "el", "sentimiento"],
    ["acontecimiento", "pasado", "por", "agua"],
    ["acoplar*", "a", "un", "plan"],
    ["acordar*", "de", "la", "madre", "de"],
    ["activa", "y", "por", "pasiva"],
    ["activo", "tóxico"],
    ["actu*", "a", "cara", "descubierta"],
    ["actu*", "con", "conocimiento", "de", "causa"],
    ["actu*", "de", "cara", "a", "la", "galería"],
    ["actu*", "en", "legítima", "defensa"],
    ["actu*", "entre", "bambalinas"],
    ["actualmente", "en", "vigor"],
    ["acus*", "recibo"],
    ["adelante", "con", "los", "faroles"],
    ["además", "de", "verdad"],
    ["adiós", "muy", "buenas"],
    ["adolecer", "de", "pegada"],
    ["ador*", "al", "santo", "por", "la", "peana"],
    ["aferrarse", "al", "cargo"],
    ["afil*", "el", "colmillo"],
    ["afloj*", "la", "mosca"],
    ["agach*", "las", "orejas"],
    ["agarra*", "a", "un", "clavo", "ardiendo"],
    ["agarrao", "que", "un", "chotis"],
    ["agentes", "del", "orden"],
    ["agita*", "en", "la", "duda"],
    ["aguant*", "carros", "y", "carretas"],
    ["aguant*", "el", "chaparrón"],
    ["aguant*", "el", "tipo"],
    ["aguant*", "el", "tirón"],
    ["aguar", "la", "fiesta"],
    ["agárrate", "que", "vienen", "curvas"],
    ["ahog*", "las", "penas", "en", "alcohol"],
    ["ahoga*", "en", "un", "vaso", "de", "agua"],
    ["ahogado", "por", "las", "deudas"],
    ["ahuec*", "el", "ala"],
    ["ahí", "es", "nada"],
    ["ahí", "le", "duele"],
    ["ahí", "me", "las", "den", "todas"],
    ["airear", "los", "trapos", "sucios"],
    ["ajo", "y", "agua"],
    ["ajust*", "cuentas"],
    ["al", "acecho"],
    ["al", "agua", "patos"],
    ["al", "alcance", "de", "su", "mano"],
    ["al", "alcance", "de", "todos", "los", "bolsillos"],
    ["al", "borde", "del", "abismo"],
    ["al", "borde", "del", "precipicio"],
    ["al", "buen", "callar", "llaman", "sancho"],
    ["al", "enemigo", "ni", "agua"],
    ["al", "filo", "del", "descanso"],
    ["al", "fin", "y", "al", "cabo"],
    ["al", "final", "del", "camino"],
    ["al", "final", "lo", "barato", "sale", "caro"],
    ["al", "garete"],
    ["al", "grano"],
    ["al", "loro"],
    ["al", "límite", "de", "sus", "fuerzas"],
    ["al", "límite"],
    ["al", "menos", "tenemos", "salud"],
    ["al", "más", "pintado"],
    ["al", "otro", "barrio"],
    ["al", "pan", "pan", "y", "al", "vino", "vino"],
    ["al", "pie", "de", "la", "letra"],
    ["al", "pie", "del", "cañón"],
    ["al", "rojo", "vivo"],
    ["al", "tuntún"],
    ["al", "último", "grito"],
    ["alborot*", "el", "gallinero"],
    ["alcanz*", "la", "gloria"],
    ["alcanz*", "la", "meta"],
    ["aledaños", "del", "estadio"],
    ["alegre", "que", "unas", "pascuas"],
    ["algo", "huele", "a", "podrido", "en", "dinamarca"],
    ["aliment*", "esperanzas"],
    ["allan*", "el", "terreno"],
    ["alma", "gemela"],
    ["alto", "el", "fuego"],
    ["alucin*", "en", "colores"],
    ["alucina", "vecina"],
    ["alz*", "el", "vuelo"],
    ["amanece", "que", "no", "es", "poco"],
    ["amarga", "derrota"],
    ["amasijo", "de", "hierros"],
    ["amigos", "de", "lo", "ajeno"],
    ["amigos", "hasta", "en", "el", "infierno"],
    ["amistad", "inquebrantable"],
    ["amor", "a", "primera", "vista"],
    ["amplio", "abanico", "de", "posibilidades"],
    ["amplio", "despliegue", "policial"],
    ["ancha", "es", "castilla"],
    ["and*", "a", "la", "greña"],
    ["and*", "a", "la", "que", "salta"],
    ["and*", "con", "chiquitas"],
    ["and*", "con", "el", "pie", "cambiado"],
    ["and*", "con", "mil", "ojos"],
    ["and*", "con", "miramientos"],
    ["and*", "con", "paños", "calientes"],
    ["and*", "con", "rodeos"],
    ["and*", "con", "tonterías"],
    ["and*", "metido", "en", "líos"],
    ["anda", "ya"],
    ["andando", "que", "es", "gerundio"],
    ["andarse", "con", "florituras"],
    ["andarse", "con", "ojo"],
    ["angustia", "y", "desesperación"],
    ["anim*", "el", "cotarro"],
    ["animal", "político"],
    ["antesala", "de", "los", "oscar"],
    ["antesala", "del", "desastre"],
    ["antesala", "del", "infierno"],
    ["antiguas", "pesetas"],
    ["antro", "de", "mala", "muerte"],
    ["anunci*", "a", "bombo", "y", "platillo"],
    ["apaga", "y", "vámonos"],
    ["apaga*", "la", "voz"],
    ["aparatoso", "accidente"],
    ["apariencias", "engañan"],
    ["apechug*", "con"],
    ["apegad*", "al", "terruño"],
    ["aplaudi*", "con", "las", "orejas"],
    ["aplic*", "doble", "vara", "de", "medir"],
    ["aplica*", "el", "cuento"],
    ["apoquin*", "dinero"],
    ["aport*", "su", "granito", "de", "arena"],
    ["apoteosis", "en", "la", "grada"],
    ["apoy*", "la", "jugada"],
    ["aprend*", "la", "lección"],
    ["apret*", "el", "cinturón"],
    ["apret*", "el", "culo"],
    ["apret*", "las", "clavijas"],
    ["apret*", "las", "tuercas"],
    ["apret*", "los", "machos"],
    ["aprovech*", "que", "el", "pisuerga", "pasa", "por", "valladolid"],
    ["apto", "para", "cardíacos"],
    ["apunt*", "maneras"],
    ["apuntarse", "a", "un", "bombardeo"],
    ["apuntarse", "un", "tanto"],
    ["aquí", "el", "más", "tonto", "hace", "relojes"],
    ["aquí", "no", "hay", "quien", "viva"],
    ["aquí", "paz", "y", "después", "gloria"],
    ["aquí", "te", "pillo", "aquí", "te", "mato"],
    ["arañ*", "segundos"],
    ["ard*", "en", "deseos"],
    ["ard*", "las", "redes"],
    ["ard*", "troya"],
    ["arenas", "movedizas"],
    ["arm*", "barullo"],
    ["arm*", "bronca"],
    ["arm*", "de", "paciencia"],
    ["arm*", "de", "valor"],
    ["arm*", "el", "belén"],
    ["arm*", "gresca"],
    ["arm*", "la", "de", "dios"],
    ["arm*", "la", "de", "san", "quintín"],
    ["arm*", "la", "gorda"],
    ["arm*", "la", "marimorena"],
    ["arm*", "un", "cisco"],
    ["arm*", "un", "pitote"],
    ["arm*", "un", "pollo"],
    ["arm*", "un", "zafarrancho"],
    ["arm*", "un", "zipizape"],
    ["arm*", "una", "gorda"],
    ["arm*", "una", "zapatiesta"],
    ["arma", "de", "doble", "filo"],
    ["armado", "hasta", "los", "dientes"],
    ["armas", "de", "grueso", "calibre"],
    ["armas", "las", "carga", "el", "diablo"],
    ["arrampl*", "con", "todo"],
    ["arras*", "literalmente", "con", "todo"],
    ["arreando", "que", "es", "gerundio"],
    ["arrieros", "somos", "y", "en", "el", "camino", "nos", "encontraremos"],
    ["arrim*", "el", "ascua", "a", "su", "sardina"],
    ["arrim*", "el", "hombro"],
    ["arrimarse", "al", "sol", "que", "más", "calienta"],
    ["arroj*", "luz"],
    ["arroj*", "un", "balance"],
    ["arroz", "para", "tan", "poco", "pollo"],
    ["arrugad*", "como", "una", "pasa"],
    ["arte", "de", "birlibirloque"],
    ["artefacto", "de", "fabricación", "casera"],
    ["artillería", "pesada"],
    ["as*", "la", "manteca"],
    ["as?nt*", "como", "un", "idiota"],
    ["asalt*", "las", "dudas"],
    ["asignatura", "pendiente"],
    ["asom*", "el", "hocico"],
    ["astro", "del", "fútbol"],
    ["astro", "rey"],
    ["asunto", "de", "estado"],
    ["asunto", "menor"],
    ["asunto", "peliagudo"],
    ["así", "gana", "el", "madrid"],
    ["así", "se", "escribe", "la", "historia"],
    ["así", "son", "las", "cosas", "y", "así", "se", "las", "hemos", "contado"],
    ["at*", "cabos"],
    ["at*", "en", "corto"],
    ["at*", "los", "perros", "con", "longaniza"],
    ["atacado", "de", "los", "nervios"],
    ["atado", "y", "bien", "atado"],
    ["ataque", "quirúrgico"],
    ["atenerse", "a", "las", "consecuencias"],
    ["aterido", "de", "frío"],
    ["atisb*", "la", "luz", "al", "final", "del", "túnel"],
    ["auténtica", "barbaridad"],
    ["auténtica", "marea", "humana"],
    ["auténtico", "hervidero", "de", "gente"],
    ["auténtico", "infierno"],
    ["avanzado", "estado", "de", "descomposición"],
    ["ave", "de", "mal", "agüero"],
    ["avecin*", "tormenta"],
    ["aviso", "a", "navegantes"],
    ["años", "no", "pasan", "en", "balde"],
    ["bail*", "al", "son", "que", "le", "tocan"],
    ["bail*", "como", "un", "pato", "mareado"],
    ["bail*", "con", "la", "más", "fea"],
    ["bail*", "el", "agua"],
    ["baile", "de", "cifras"],
    ["baj*", "a", "tierra"],
    ["baj*", "al", "barro"],
    ["baj*", "de", "las", "nubes"],
    ["baj*", "del", "burro"],
    ["baj*", "del", "carro"],
    ["baj*", "del", "pedestal"],
    ["baj*", "la", "bandera"],
    ["baj*", "la", "guardia"],
    ["baj*", "los", "humos"],
    ["baje", "dios", "y", "lo", "vea"],
    ["bajo", "cuerda"],
    ["bajo", "trágicas", "circunstancias"],
    ["balance", "positivo"],
    ["balón", "a", "la", "olla"],
    ["balón", "de", "oxígeno"],
    ["banco", "azul"],
    ["baraj*", "distintas", "posibilidades"],
    ["barr*", "para", "casa"],
    ["barrera", "psicológica"],
    ["bat*", "el", "cobre"],
    ["bat*", "en", "retirada"],
    ["batacazo", "bursátil"],
    ["batacazo", "electoral"],
    ["batalla", "campal"],
    ["batalla", "perdida"],
    ["bautismo", "de", "fuego"],
    ["baño", "de", "masas"],
    ["baño", "de", "sangre"],
    ["beb*", "como", "un", "cosaco"],
    ["beb*", "los", "vientos"],
    ["belleza", "exquisita"],
    ["beneficio", "de", "inventario"],
    ["beso", "de", "judas"],
    ["bestia", "negra"],
    ["bestia", "parda"],
    ["biblia", "en", "verso"],
    ["bicho", "viviente"],
    ["bien", "de", "la", "azotea"],
    ["blanco", "como", "la", "nieve"],
    ["blanco", "inmaculado"],
    ["blanco", "sobre", "negro"],
    ["blanco", "y", "en", "botella"],
    ["blanque*", "dinero", "negro"],
    ["bocachancla"],
    ["boda", "del", "siglo"],
    ["bola", "de", "billar"],
    ["bolas", "estaban", "perezosas"],
    ["bolsa", "cae", "a", "mínimos", "históricos"],
    ["bolsa", "de", "pobreza"],
    ["bomba", "de", "relojería"],
    ["bomba", "inteligente"],
    ["bombo", "y", "platillo"],
    ["boquita", "de", "piñón"],
    ["bord*", "algo"],
    ["borr*", "del", "mapa"],
    ["borrón", "y", "cuenta", "nueva"],
    ["bote", "pronto"],
    ["brazo", "a", "torcer"],
    ["brill*", "con", "luz", "propia"],
    ["brill*", "por", "su", "ausencia"],
    ["brind*", "apoyo"],
    ["brindis", "al", "sol"],
    ["bromas", "aparte"],
    ["brutal", "paliza"],
    ["bruto", "que", "un", "arado"],
    ["buen", "partido"],
    ["buen", "recaudo"],
    ["buena", "gente"],
    ["buena", "sintonía"],
    ["bueno", "que", "el", "pan"],
    ["burbuja", "inmobiliaria"],
    ["busc*", "con", "la", "mirada"],
    ["busc*", "la", "vida"],
    ["busc*", "las", "cosquillas"],
    ["busc*", "las", "habichuelas"],
    ["busc*", "tres", "pies", "al", "gato"],
    ["busc*", "una", "aguja", "en", "un", "pajar"],
    ["busca", "interpel*", "al", "espectador"],
    ["ca*", "a", "pedazos"],
    ["ca*", "chuzos", "de", "punta"],
    ["ca*", "como", "fruta", "madura"],
    ["ca*", "como", "llovido", "del", "cielo"],
    ["ca*", "como", "un", "jarro", "de", "agua", "fría"],
    ["ca*", "con", "todo", "el", "equipo"],
    ["ca*", "cuatro", "gotas"],
    ["ca*", "de", "pie"],
    ["ca*", "del", "burro"],
    ["ca*", "del", "guindo"],
    ["ca*", "en", "la", "cuenta"],
    ["ca*", "en", "la", "tentación"],
    ["ca*", "en", "la", "trampa"],
    ["ca*", "en", "picado"],
    ["ca*", "en", "saco", "roto"],
    ["ca*", "gordo"],
    ["ca*", "la", "baba", "con"],
    ["ca*", "la", "cara", "de", "vergüenza"],
    ["ca*", "la", "casa", "encima"],
    ["ca*", "la", "del", "pulpo"],
    ["ca*", "la", "venda", "de", "los", "ojos"],
    ["ca*", "los", "palos", "del", "sombrajo"],
    ["ca*", "muy", "bajo"],
    ["ca*", "por", "su", "propio", "peso"],
    ["caballo", "ganador"],
    ["cabe", "ni", "un", "alfiler"],
    ["cabe", "ni", "un", "alma"],
    ["cabeza", "bien", "amueblada"],
    ["cabeza", "buque"],
    ["cabeza", "como", "un", "bombo"],
    ["cabeza", "cuadrada"],
    ["cabeza", "de", "chorlito"],
    ["cabeza", "de", "turco"],
    ["cabeza", "en", "su", "sitio"],
    ["cabeza", "hueca"],
    ["cabeza", "llena", "de", "pájaros"],
    ["cabra", "loca"],
    ["cabra", "tira", "al", "monte"],
    ["cachondo", "mental"],
    ["cada", "dos", "por", "tres"],
    ["cada", "loco", "con", "su", "tema"],
    ["cada", "mochuelo", "a", "su", "olivo"],
    ["cada", "palo", "aguante", "su", "vela"],
    ["cada", "uno", "de", "su", "padre", "y", "de", "su", "madre"],
    ["caerá", "esa", "breva"],
    ["caiga", "quien", "caiga"],
    ["caja", "tonta"],
    ["cala*", "hasta", "los", "huesos"],
    ["calde*", "el", "ambiente"],
    ["caldo", "de", "cultivo"],
    ["calent*", "el", "ambiente"],
    ["calent*", "el", "banquillo"],
    ["calent*", "la", "boca"],
    ["calent*", "la", "cabeza"],
    ["calent*", "la", "silla"],
    ["calent*", "motores"],
    ["caliente", "que", "un", "cazo"],
    ["call*", "como", "un", "muerto"],
    ["call*", "muchas", "bocas"],
    ["call*", "para", "siempre"],
    ["calm*", "los", "mercados"],
    ["calma", "chicha"],
    ["calma", "después", "de", "la", "tormenta"],
    ["calma", "tensa"],
    ["calor", "abrasador"],
    ["calor", "infernal"],
    ["calumnia", "que", "algo", "queda"],
    ["caluroso", "recibimiento"],
    ["calvario", "judicial"],
    ["cambi*", "de", "aires"],
    ["cambi*", "de", "chaqueta"],
    ["cambi*", "de", "disco"],
    ["cambi*", "de", "rumbo"],
    ["cambi*", "el", "chip"],
    ["cambi*", "la", "narrativa"],
    ["cambiarle", "el", "agua", "al", "canario"],
    ["camino", "de", "rosas"],
    ["camino", "sin", "retorno"],
    ["camisa", "de", "once", "varas"],
    ["camp*", "a", "sus", "anchas"],
    ["canasta", "sobre", "la", "bocina"],
    ["canela", "fina"],
    ["cant*", "como", "los", "ángeles"],
    ["cant*", "de", "plano"],
    ["cant*", "el", "alirón"],
    ["cant*", "la", "traviata"],
    ["cant*", "las", "cuarenta"],
    ["cant*", "los", "pinreles"],
    ["cant*", "victoria"],
    ["cantar", "victoria"],
    ["cantos", "de", "sirenas"],
    ["cap*", "el", "temporal"],
    ["capital", "humano"],
    ["cara", "de", "mala", "leche"],
    ["cara", "de", "no", "haber", "roto", "nunca", "un", "plato"],
    ["cara", "de", "pocos", "amigos"],
    ["cara", "de", "póquer"],
    ["cara", "de", "vinagre"],
    ["cara", "muy", "dura"],
    ["carabina", "de", "ambrosio"],
    ["cardo", "borriquero"],
    ["carg*", "con", "el", "mochuelo"],
    ["carg*", "con", "el", "muerto"],
    ["carg*", "las", "pilas"],
    ["carg*", "las", "tintas"],
    ["carne", "de", "burro", "no", "*", "transparent?"],
    ["carne", "de", "cañón"],
    ["carne", "de", "meme"],
    ["carrera", "meteórica"],
    ["carretera", "y", "manta"],
    ["carta", "magna"],
    ["cartas", "en", "el", "asunto"],
    ["cas*", "de", "penalti"],
    ["casa", "de", "locos"],
    ["casa", "de", "tócame", "roque"],
    ["castig*", "con", "la", "mirada"],
    ["castillo", "de", "naipes"],
    ["caus*", "furor"],
    ["causO", "estragos"],
    ["cav*", "su", "propia", "tumba"],
    ["cavarle", "la", "tumba"],
    ["caverna", "mediática"],
    ["caza", "de", "brujas"],
    ["cazador", "cazado"],
    ["cazarlas", "al", "vuelo"],
    ["caída", "libre"],
    ["cebarse", "con"],
    ["cementerio", "de", "elefantes"],
    ["cenicienta", "del", "grupo"],
    ["cenizo"],
    ["centro", "neurálgico"],
    ["cero", "a", "la", "izquierda"],
    ["cero", "patatero"],
    ["cerr*", "a", "cal", "y", "canto"],
    ["cerr*", "con", "broche", "de", "oro"],
    ["cerr*", "el", "chiringuito"],
    ["cerr*", "el", "grifo"],
    ["cerr*", "el", "pico"],
    ["cerr*", "en", "banda"],
    ["cerr*", "filas"],
    ["cerr*", "las", "puertas"],
    ["cerr*", "los", "últimos", "flecos"],
    ["cerrada", "ovación"],
    ["cese", "temporal", "de", "la", "convivencia"],
    ["ceñi*", "a", "los", "hechos"],
    ["chap*", "un", "lug*"],
    ["chapad*", "a", "la", "antigua"],
    ["chicas", "son", "guerreras"],
    ["chicha", "ni", "limoná"],
    ["china", "en", "el", "zapato"],
    ["chinch*"],
    ["choc*", "los", "cinco"],
    ["choque", "de", "trenes"],
    ["chulo", "que", "un", "ocho"],
    ["chup*", "balón"],
    ["chup*", "banquillo"],
    ["chup*", "cámara"],
    ["chup*", "del", "bote"],
    ["chup*", "los", "dedos"],
    ["chup*", "rueda"],
    ["churras", "con", "merinas"],
    ["chut*", "en", "vena"],
    ["ciencias", "avanzan", "una", "barbaridad"],
    ["ciento", "y", "la", "madre"],
    ["cifra", "astronómica"],
    ["cita", "decisiva", "en", "las", "urnas"],
    ["cita", "ineludible"],
    ["ciudadano", "de", "a", "pie"],
    ["ciudadano", "del", "mundo"],
    ["ciudadanos", "tienen", "la", "palabra"],
    ["clam*", "al", "cielo"],
    ["claro", "exponente"],
    ["clases", "sociales", "más", "desfavorecidas"],
    ["clavo", "saca", "a", "otro", "clavo"],
    ["climatología", "adversa"],
    ["cobr*", "vidas"],
    ["cocin*", "para", "un", "regimiento"],
    ["cog*", "al", "vuelo"],
    ["cog*", "carrerilla"],
    ["cog*", "con", "alfileres"],
    ["cog*", "con", "pinzas"],
    ["cog*", "el", "relevo"],
    ["cog*", "el", "rábano", "por", "las", "hojas"],
    ["cog*", "el", "toro", "por", "los", "cuernos"],
    ["cog*", "el", "tranquillo"],
    ["cog*", "el", "último", "tren"],
    ["cog*", "fuerzas"],
    ["cog*", "la", "alternativa"],
    ["cog*", "las", "cosas", "al", "vuelo"],
    ["cog*", "por", "banda"],
    ["cog*", "un", "rebote"],
    ["cog*", "un", "trancazo"],
    ["cogida", "la", "medida"],
    ["cogido", "por", "las", "pelotas"],
    ["coje*", "del", "mismo", "pie"],
    ["colg*", "el", "cartel", "de", "no", "hay", "billetes"],
    ["colg*", "el", "cartel", "de", "no", "hay", "entradas"],
    ["colg*", "el", "sambenito"],
    ["colg*", "las", "botas"],
    ["colg*", "los", "guantes"],
    ["colg*", "los", "hábitos"],
    ["colg*", "medallas"],
    ["colgado", "que", "una", "percha"],
    ["colm*", "todas", "las", "expectativas"],
    ["colmillo", "retorcido", "afilado"],
    ["coloc*", "a", "dedo"],
    ["colofón", "final"],
    ["colorín", "colorado", "este", "cuento", "se", "ha", "acabado"],
    ["columpi*", "sobre", "un", "tema"],
    ["com*", "a", "besos"],
    ["com*", "a", "dos", "carrillos"],
    ["com*", "como", "un", "cerdo"],
    ["com*", "como", "un", "descosido"],
    ["com*", "como", "una", "lima"],
    ["com*", "con", "los", "ojos"],
    ["com*", "el", "coco"],
    ["com*", "el", "tarro"],
    ["com*", "en", "el", "mismo", "plato"],
    ["com*", "menos", "que", "un", "pajarito"],
    ["com*", "un", "marrón"],
    ["combat*", "cuerpo", "a", "cuerpo"],
    ["combate", "cuerpo", "a", "cuerpo"],
    ["come", "y", "calla"],
    ["coment*", "la", "jugada"],
    ["comicios", "históricos"],
    ["comido", "por", "lo", "servido"],
    ["comienz*", "la", "cuenta", "atrás"],
    ["comienzos", "siempre", "son", "difíciles"],
    ["como", "a", "un", "cristo", "dos", "pistolas"],
    ["como", "agua", "de", "mayo"],
    ["como", "alma", "en", "pena"],
    ["como", "aquel", "que", "dice"],
    ["como", "bien", "ha*", "dicho"],
    ["como", "caído", "del", "cielo"],
    ["como", "dios", "lo*", "trajo", "al", "mundo"],
    ["como", "dios", "manda"],
    ["como", "el", "agua", "y", "el", "aceite"],
    ["como", "el", "perro", "del", "hortelano"],
    ["como", "el", "perro", "y", "el", "gato"],
    ["como", "el", "que", "no", "quiere", "la", "cosa"],
    ["como", "el", "quico"],
    ["como", "era", "de", "esperar"],
    ["como", "gato", "panza", "arriba"],
    ["como", "la", "copa", "de", "un", "pino"],
    ["como", "la", "mojama"],
    ["como", "la", "vida", "misma"],
    ["como", "los", "chorros", "del", "oro"],
    ["como", "manda", "la", "tradición"],
    ["como", "muestra", "un", "botón"],
    ["como", "no", "podía", "ser", "de", "otro", "modo"],
    ["como", "oro", "en", "paño"],
    ["como", "pedro", "por", "su", "casa"],
    ["como", "pez", "en", "el", "agua"],
    ["como", "piojos", "en", "costura"],
    ["como", "pollo", "sin", "cabeza"],
    ["como", "que", "no", "quiere", "la", "cosa"],
    ["como", "quien", "no", "quiere", "la", "cosa"],
    ["como", "quien", "oye", "llover"],
    ["como", "sardinas", "en", "lata"],
    ["como", "si", "tal", "cosa"],
    ["como", "tal"],
    ["como", "todo", "el", "mundo", "sabe"],
    ["como", "todo", "hijo", "de", "vecino"],
    ["como", "un", "castillo", "de", "naipes"],
    ["como", "un", "huevo", "a", "una", "castaña"],
    ["como", "un", "lagarto"],
    ["como", "un", "libro", "abierto"],
    ["como", "un", "niño", "con", "zapatos", "nuevos"],
    ["como", "un", "pato", "mareao"],
    ["como", "un", "roble"],
    ["como", "un", "rodillo"],
    ["como", "un", "solo", "hombre"],
    ["como", "un", "toro"],
    ["como", "un", "tren"],
    ["como", "una", "bala"],
    ["como", "una", "cabra"],
    ["como", "una", "flecha"],
    ["como", "una", "moto"],
    ["como", "una", "patena"],
    ["como", "una", "regadera"],
    ["como", "unas", "castañuelas"],
    ["comportamiento", "inapropiado"],
    ["compuesta", "y", "sin", "novio"],
    ["comulga*", "con", "ruedas", "de", "molino"],
    ["con", "buena", "estrella"],
    ["con", "buenos", "ojos"],
    ["con", "cabeza"],
    ["con", "cuentagotas"],
    ["con", "cuentos"],
    ["con", "dos", "palmos", "de", "narices"],
    ["con", "el", "agua", "al", "cuello"],
    ["con", "el", "lirio", "en", "la", "mano"],
    ["con", "el", "pie", "cambiado"],
    ["con", "el", "piloto", "económico"],
    ["con", "el", "rabo", "entre", "las", "piernas"],
    ["con", "el", "viento", "de", "cara"],
    ["con", "esa", "idea", "en", "la", "cabeza"],
    ["con", "esto", "y", "un", "bizcocho", "hasta", "mañana", "a", "las", "ocho"],
    ["con", "la", "boca", "abierta"],
    ["con", "la", "cabeza", "bien", "alta"],
    ["con", "la", "cara", "larga"],
    ["con", "la", "cruz", "a", "cuestas"],
    ["con", "la", "gorra"],
    ["con", "la", "iglesia", "hemos", "topado"],
    ["con", "la", "lengua", "fuera"],
    ["con", "la", "mirada", "perdida"],
    ["con", "la", "mosca", "detrás", "de", "la", "oreja"],
    ["con", "la", "música", "a", "otra", "parte"],
    ["con", "la", "música", "a", "todo", "trapo"],
    ["con", "la", "pierna", "cambiada"],
    ["con", "la", "pólvora", "mojada"],
    ["con", "la", "que", "está", "cayendo"],
    ["con", "la", "soga", "al", "cuello"],
    ["con", "los", "ojos", "cerrados"],
    ["con", "los", "pies", "en", "el", "suelo"],
    ["con", "los", "pies", "en", "la", "tierra"],
    ["con", "luz", "y", "taquígrafos"],
    ["con", "malos", "ojos"],
    ["con", "mis", "mejores", "deseos"],
    ["con", "muestras", "de", "profundo", "pesar"],
    ["con", "nocturnidad", "y", "alevosía"],
    ["con", "paso", "firme", "y", "decidido"],
    ["con", "paños", "calientes"],
    ["con", "pelos", "y", "señales"],
    ["con", "pies", "de", "plomo"],
    ["con", "su", "pan", "se", "lo", "coma"],
    ["con", "todo", "lujo", "de", "detalles"],
    ["con", "total", "normalidad"],
    ["con", "un", "palmo", "de", "narices"],
    ["con", "un", "pan", "bajo", "el", "brazo"],
    ["conato", "de", "incendio"],
    ["conced*", "un", "baile"],
    ["conciencia", "tranquila"],
    ["confund*", "la", "velocidad", "con", "el", "tocino"],
    ["congelación", "salarial"],
    ["cono*", "como", "si", "le", "hubiera", "parido"],
    ["conoc*", "algo", "como", "la", "palma", "de", "su", "mano"],
    ["conoc*", "el", "percal"],
    ["consultar*", "con", "la", "almohada"],
    ["cont*", "batallitas"],
    ["cont*", "trolas"],
    ["cont*", "una", "bola"],
    ["contagia*", "la", "euforia"],
    ["contigo", "al", "fin", "del", "mundo"],
    ["contigo", "pan", "y", "cebolla"],
    ["contra", "las", "cuerdas"],
    ["contra", "los", "elementos"],
    ["contra", "viento", "y", "marea"],
    ["converti*", "en", "*", "peor", "pesadilla"],
    ["convidado", "de", "piedra"],
    ["cop*", "los", "puestos", "de", "salida"],
    ["cop*", "los", "titulares"],
    ["copiosa", "lluvia"],
    ["coquete*", "con", "otras", "ideas"],
    ["corazón", "de", "piedra"],
    ["cornudo", "y", "apaleado"],
    ["corr*", "como", "alma", "que", "lleva", "el", "diablo"],
    ["corr*", "como", "la", "pólvora"],
    ["corr*", "como", "pollo", "sin", "cabeza"],
    ["corr*", "de", "boca", "en", "boca"],
    ["corr*", "la", "voz"],
    ["corr*", "ríos", "de", "tinta"],
    ["corr*", "un", "tupido", "velo"],
    ["corr*", "una", "suerte", "muy", "dispar"],
    ["correa", "de", "transmisión"],
    ["corren", "malos", "tiempos", "para", "la", "lírica"],
    ["corren", "malos", "tiempos"],
    ["corriente", "y", "moliente"],
    ["cort*", "cabezas"],
    ["cort*", "el", "bacalao"],
    ["cort*", "el", "grifo"],
    ["cort*", "la", "coleta"],
    ["cort*", "la", "respiración"],
    ["cort*", "las", "alas"],
    ["cort*", "las", "dos", "orejas", "y", "el", "rabo"],
    ["cort*", "las", "venas"],
    ["cort*", "por", "lo", "sano"],
    ["cortina", "de", "humo"],
    ["corto", "ni", "perezoso"],
    ["cosa", "de", "poco"],
    ["cosa", "está", "que", "arde"],
    ["cosa", "mala"],
    ["cosa", "no", "tiene", "más", "misterio"],
    ["cosas", "veredes"],
    ["coser", "y", "cantar"],
    ["cost*", "caro"],
    ["cost*", "cuatro", "perras"],
    ["cost*", "dios", "y", "ayuda"],
    ["cost*", "la", "torta", "un", "pan"],
    ["cost*", "un", "huevo"],
    ["cost*", "un", "ojo", "de", "la", "cara"],
    ["cost*", "un", "pastizal"],
    ["cost*", "un", "riñón"],
    ["cost*", "una", "pasta", "gansa"],
    ["costumbre", "muy", "arraigada"],
    ["craso", "error"],
    ["cre*", "algo", "a", "pies", "juntillas"],
    ["cre*", "el", "ombligo", "del", "mundo"],
    ["crea*", "escuela"],
    ["crec*", "ante", "la", "adversidad"],
    ["crec*", "como", "la", "espuma"],
    ["crec*", "como", "setas"],
    ["crecimiento", "negativo"],
    ["cri*", "malvas"],
    ["crimen", "pasional"],
    ["cristiana", "sepultura"],
    ["cruda", "realidad"],
    ["cruz", "y", "raya"],
    ["cruz*", "el", "charco"],
    ["cruz*", "la", "raya"],
    ["cruz*", "los", "cables"],
    ["crédito", "a", "lo", "que", "ven", "mis", "ojos"],
    ["crónica", "de", "una…", "anunciada"],
    ["cualquier", "tiempo", "pasado", "fue", "mejor"],
    ["cualquiera", "lo", "diría"],
    ["cuando", "el", "río", "suena"],
    ["cuando", "las", "ranas", "críen", "pelo"],
    ["cuantiosas", "pérdidas"],
    ["cuanto", "mejor", "peor"],
    ["cuatro", "ojos", "ven", "más", "que", "dos"],
    ["cubr*", "distancias"],
    ["cubr*", "el", "expediente"],
    ["cubr*", "un", "hueco"],
    ["cubrirse", "las", "espaldas"],
    ["cuello", "de", "cisne"],
    ["cuenta", "de", "la", "vieja"],
    ["cuentas", "claras"],
    ["cuentas", "del", "gran", "capitán"],
    ["cuento", "chino"],
    ["cuerda", "para", "rato"],
    ["cuerpo", "de", "rey"],
    ["cuerpo", "sin", "vida"],
    ["cuesta", "de", "enero"],
    ["cuestión", "de", "horas"],
    ["cuestión", "de", "vida", "o", "muerte"],
    ["culo", "de", "mal", "asiento"],
    ["culo", "inquieto"],
    ["cumpl*", "con", "el", "deber", "cívico"],
    ["cunda", "el", "ejemplo"],
    ["cunda", "el", "pánico"],
    ["cur*", "en", "salud"],
    ["curiosidad", "mató", "al", "gato"],
    ["cálida", "ovación"],
    ["círculo", "vicioso"],
    ["círculos", "bien", "informados"],
    ["cómo", "está", "el", "patio"],
    ["cómodos", "plazos", "mensuales"],
    ["cúmulo", "de", "desgracias"],
    ["cúmulo", "de", "falsedades"],
    ["d*", "a", "la", "bebida"],
    ["d*", "a", "la", "fuga"],
    ["d*", "a", "la", "lengua"],
    ["d*", "a", "la", "sin", "hueso"],
    ["d*", "al", "traste", "con", "algo"],
    ["d*", "autobombo"],
    ["d*", "bola"],
    ["d*", "buena", "cuenta", "de", "algo"],
    ["d*", "calabazas"],
    ["d*", "cancha"],
    ["d*", "candela"],
    ["d*", "carpetazo", "a", "un"],
    ["d*", "carta", "blanca"],
    ["d*", "cartas", "en", "el", "asunto"],
    ["d*", "caña"],
    ["d*", "cien", "vueltas"],
    ["d*", "coba"],
    ["d*", "coces"],
    ["d*", "con", "la", "tecla"],
    ["d*", "con", "tus", "huesos", "en", "un", "sitio"],
    ["d*", "con", "un", "canto", "en", "los", "dientes"],
    ["d*", "cosa"],
    ["d*", "cuerda"],
    ["d*", "de", "bruces", "con"],
    ["d*", "de", "morros", "con"],
    ["d*", "el", "110", "por", "ciento"],
    ["d*", "el", "beso", "de", "judas"],
    ["d*", "el", "braguetazo"],
    ["d*", "el", "callo"],
    ["d*", "el", "cambiazo"],
    ["d*", "el", "cante"],
    ["d*", "el", "do", "de", "pecho"],
    ["d*", "el", "lote"],
    ["d*", "el", "pego"],
    ["d*", "el", "pisto"],
    ["d*", "el", "pistoletazo", "de", "salida"],
    ["d*", "el", "tiro", "de", "gracia"],
    ["d*", "el", "visto", "bueno"],
    ["d*", "el", "último", "adiós"],
    ["d*", "en", "el", "blanco"],
    ["d*", "en", "el", "clavo"],
    ["d*", "en", "la", "diana"],
    ["d*", "esquinazo"],
    ["d*", "gato", "por", "liebre"],
    ["d*", "igual", "ocho", "que", "ochenta"],
    ["d*", "jabón"],
    ["d*", "la", "brasa"],
    ["d*", "la", "callada", "por", "respuesta"],
    ["d*", "la", "campanada"],
    ["d*", "la", "cara", "por"],
    ["d*", "la", "chapa"],
    ["d*", "la", "espalda"],
    ["d*", "la", "espantada"],
    ["d*", "la", "lata"],
    ["d*", "la", "matraca"],
    ["d*", "la", "murga"],
    ["d*", "la", "nota"],
    ["d*", "la", "puntilla"],
    ["d*", "la", "tabarra"],
    ["d*", "la", "talla"],
    ["d*", "la", "vara"],
    ["d*", "la", "vuelta", "a", "la", "tortilla"],
    ["d*", "la", "vuelta", "al", "marcador"],
    ["d*", "la", "vuelta", "al", "ruedo"],
    ["d*", "la", "vuelta", "como", "un", "calcetín"],
    ["d*", "largas"],
    ["d*", "las", "uvas"],
    ["d*", "las", "verdades", "a", "la", "cara"],
    ["d*", "leña", "al", "mono", "que", "es", "de", "goma"],
    ["d*", "los", "últimos", "coletazos"],
    ["d*", "luz", "verde"],
    ["d*", "mala", "espina"],
    ["d*", "marcha", "atrás"],
    ["d*", "mil", "vueltas", "a"],
    ["d*", "más", "guerra", "que", "un", "niño", "chico"],
    ["d*", "palos", "de", "ciego"],
    ["d*", "para", "el", "pelo"],
    ["d*", "pasaporte"],
    ["d*", "patadas", "al", "diccionario"],
    ["d*", "plantón"],
    ["d*", "por", "aludido"],
    ["d*", "por", "sentado"],
    ["d*", "por", "vencido"],
    ["d*", "puerta"],
    ["d*", "qué", "pensar"],
    ["d*", "repelús"],
    ["d*", "rienda", "suelta"],
    ["d*", "sopas", "con", "honda"],
    ["d*", "un", "arrechucho"],
    ["d*", "un", "atracón"],
    ["d*", "un", "baño", "de", "masas"],
    ["d*", "un", "baño"],
    ["d*", "un", "cheque", "en", "blanco"],
    ["d*", "un", "corte", "de", "mangas"],
    ["d*", "un", "espaldarazo"],
    ["d*", "un", "festín"],
    ["d*", "un", "fuerte", "aplauso"],
    ["d*", "un", "golpe", "de", "timón"],
    ["d*", "un", "golpe", "sobre", "la", "mesa"],
    ["d*", "un", "homenaje"],
    ["d*", "un", "palo", "al", "agua"],
    ["d*", "un", "paso", "al", "frente"],
    ["d*", "un", "patatús"],
    ["d*", "un", "pelotazo"],
    ["d*", "un", "quiebro"],
    ["d*", "un", "recital", "de", "goles"],
    ["d*", "un", "repaso"],
    ["d*", "un", "sablazo"],
    ["d*", "un", "soponcio"],
    ["d*", "un", "sorpasso"],
    ["d*", "un", "telele"],
    ["d*", "un", "tirón", "de", "orejas"],
    ["d*", "un", "toque", "de", "atención"],
    ["d*", "un", "ultimátum"],
    ["d*", "un", "vuelco"],
    ["d*", "una", "cabezada"],
    ["d*", "una", "de", "cal", "y", "otra", "de", "arena"],
    ["d*", "una", "palmadita", "amistosa"],
    ["d*", "una", "puñalada", "trapera"],
    ["d*", "unas", "pinceladas"],
    ["d*", "vergüenza", "ajena"],
    ["d*", "zapatazos"],
    ["d?rm*", "a", "pierna", "suelta"],
    ["d?rm*", "como", "un", "ceporro"],
    ["d?rm*", "como", "un", "lirón"],
    ["d?rm*", "el", "sueño", "de", "los", "justos"],
    ["d?rm*", "en", "los", "laureles"],
    ["d?rm*", "la", "mona"],
    ["da", "lo", "mismo", "ocho", "que", "ochenta"],
    ["da*", "pie"],
    ["da*", "todo"],
    ["da*", "un", "paso", "atrás"],
    ["da[rn]", "las", "uvas"],
    ["dale", "que", "te", "pego"],
    ["dantesco", "incendio"],
    ["dar*", "con", "queso"],
    ["dardo", "envenenado"],
    ["darse", "por", "aludido"],
    ["data*", "de", "tiempo", "inmemorial"],
    ["daños", "colaterales"],
    ["de", "alto", "voltaje"],
    ["de", "andar", "por", "casa"],
    ["de", "aquellos", "barros", "estos", "lodos"],
    ["de", "aquí", "a", "lima"],
    ["de", "aquí", "te", "espero"],
    ["de", "armas", "tomar"],
    ["de", "bote", "en", "bote"],
    ["de", "buena", "cepa"],
    ["de", "buena", "pasta"],
    ["de", "buenas", "a", "primeras"],
    ["de", "cabecera"],
    ["de", "cabo", "a", "rabo"],
    ["de", "campeonato"],
    ["de", "capa", "caída"],
    ["de", "cara", "a", "la", "galería"],
    ["de", "cara", "a", "mañana"],
    ["de", "cara", "a"],
    ["de", "carambola"],
    ["de", "casta", "le", "viene", "al", "galgo"],
    ["de", "castaño", "a", "oscuro"],
    ["de", "chiripa"],
    ["de", "cine"],
    ["de", "color", "de", "rosa"],
    ["de", "eso", "nada", "monada"],
    ["de", "farol"],
    ["de", "flor", "en", "flor"],
    ["de", "fábula"],
    ["de", "golpe", "y", "porrazo"],
    ["de", "gorra"],
    ["de", "gran", "calado"],
    ["de", "guay"],
    ["de", "higos", "a", "brevas"],
    ["de", "hombre", "a", "hombre"],
    ["de", "hoz", "y", "coz"],
    ["de", "la", "ceca", "a", "la", "meca"],
    ["de", "la", "discordia"],
    ["de", "la", "lengua"],
    ["de", "la", "misa", "la", "media"],
    ["de", "la", "noche", "a", "la", "mañana"],
    ["de", "las", "cenizas", "como", "el", "ave", "fénix"],
    ["de", "listillo"],
    ["de", "lo", "que", "no", "hay"],
    ["de", "los", "nervios"],
    ["de", "lujo"],
    ["de", "lágrima", "fácil"],
    ["de", "mal", "en", "peor"],
    ["de", "mano", "en", "mano"],
    ["de", "menos", "a", "más"],
    ["de", "mi", "cosecha"],
    ["de", "mil", "amores"],
    ["de", "mil", "demonios"],
    ["de", "morros"],
    ["de", "no", "ser", "trágica", "la", "situación", "sería", "cómica"],
    ["de", "noche", "todos", "los", "gatos", "son", "pardos"],
    ["de", "oreja", "a", "oreja"],
    ["de", "padre", "y", "muy", "señor", "mío"],
    ["de", "parranda"],
    ["de", "pascuas", "a", "ramos"],
    ["de", "pe", "a", "pa"],
    ["de", "pelo", "en", "pecho"],
    ["de", "pena"],
    ["de", "perdidos", "al", "río"],
    ["de", "perfil", "bajo"],
    ["de", "perilla"],
    ["de", "perogrullo"],
    ["de", "picos", "pardos"],
    ["de", "poca", "monta"],
    ["de", "poder", "a", "poder"],
    ["de", "propios", "y", "extraños"],
    ["de", "punta", "en", "blanco"],
    ["de", "pura", "cepa"],
    ["de", "quita", "y", "pon"],
    ["de", "rabiosa", "actualidad"],
    ["de", "rositas"],
    ["de", "sol", "a", "sol"],
    ["de", "tapadillo"],
    ["de", "tiros", "largos"],
    ["de", "toda", "la", "vida"],
    ["de", "todo", "como", "en", "botica"],
    ["de", "todo", "hay", "en", "la", "viña", "del", "señor"],
    ["de", "todo", "tipo", "y", "condición"],
    ["de", "tomo", "y", "lomo"],
    ["de", "trapillo"],
    ["de", "tres", "al", "cuarto"],
    ["de", "un", "tiempo", "a", "esta", "parte"],
    ["de", "una", "vez", "por", "todas"],
    ["de", "uvas", "a", "peras"],
    ["de", "uñas"],
    ["de", "viva", "voz"],
    ["de", "vuelta", "y", "media"],
    ["de", "vértigo"],
    ["de", "última", "generación"],
    ["deambul*", "sin", "rumbo"],
    ["debat*", "entre", "la", "vida", "y", "la", "muerte"],
    ["debut", "prometedor"],
    ["dec*", "con", "la", "boca", "pequeña"],
    ["dec*", "con", "recochineo"],
    ["dec*", "con", "retintín"],
    ["dec*", "cuatro", "cosas", "bien", "dichas"],
    ["dec*", "de", "boquilla"],
    ["dec*", "esta", "boca", "es", "mía"],
    ["dec*", "las", "verdades", "del", "barquero"],
    ["dec*", "paridas"],
    ["dechado", "de", "virtudes"],
    ["decisión", "salomónica"],
    ["declar*", "la", "guerra"],
    ["declar*", "un", "incendio"],
    ["defend*", "a", "capa", "y", "espada"],
    ["defend*", "con", "uñas", "y", "dientes"],
    ["defensa", "numantina"],
    ["dej*", "a", "la", "altura", "del", "betún"],
    ["dej*", "a", "los", "pies", "de", "los", "caballos"],
    ["dej*", "colgado"],
    ["dej*", "como", "los", "chorros", "del", "oro"],
    ["dej*", "con", "la", "miel", "en", "los", "labios"],
    ["dej*", "con", "la", "palabra", "en", "la", "boca"],
    ["dej*", "de", "chorradas"],
    ["dej*", "de", "gaitas"],
    ["dej*", "de", "monsergas"],
    ["dej*", "de", "rodeos"],
    ["dej*", "de", "tonterías"],
    ["dej*", "el", "nido"],
    ["dej*", "el", "pabellón", "bien", "alto"],
    ["dej*", "el", "pellejo"],
    ["dej*", "en", "bragas"],
    ["dej*", "en", "la", "estacada"],
    ["dej*", "en", "mal", "lugar"],
    ["dej*", "huella"],
    ["dej*", "la", "piel"],
    ["dej*", "los", "puntos", "por", "el", "camino"],
    ["dej*", "los", "tres", "puntos", "en", "casa"],
    ["dej*", "mucho", "que", "desear"],
    ["dej*", "muerto"],
    ["dej*", "ni", "las", "migajas"],
    ["dej*", "pasar", "el", "tren"],
    ["dej*", "patidifuso"],
    ["dej*", "plantado"],
    ["dej*", "tirado"],
    ["dej*", "todo", "manga", "por", "hombro"],
    ["dej*", "un", "cabo", "suelto"],
    ["dej*", "un", "regalito"],
    ["dej*", "un", "saldo", "de"],
    ["dej*", "vendido"],
    ["dej*", "visto", "para", "sentencia"],
    ["dejado", "de", "la", "mano", "de", "dios"],
    ["del", "año", "catapúm"],
    ["del", "año", "de", "la", "polca"],
    ["del", "tamaño", "de", "un", "campo", "de", "fútbol"],
    ["del", "tamaño", "de", "una", "piscina", "olímpica"],
    ["delirios", "de", "grandeza"],
    ["demostr*", "con", "creces"],
    ["densa", "humareda"],
    ["densas", "columnas", "de", "humo"],
    ["dentro", "de", "lo", "que", "cabe"],
    ["depur*", "responsabilidades"],
    ["derecho", "a", "roce"],
    ["derrap*", "en", "un", "tema"],
    ["derrota", "sin", "paliativos"],
    ["desaceleración", "económica"],
    ["desat*", "el", "caos"],
    ["desat*", "las", "críticas"],
    ["descalabro", "electoral"],
    ["descerraj*", "un", "tiro"],
    ["desconect*", "el", "fin", "de", "semana"],
    ["descongelación", "salarial"],
    ["desconsolada", "viuda"],
    ["descubr*", "américa"],
    ["descubr*", "el", "mediterráneo"],
    ["descubr*", "el", "pastel"],
    ["descubr*", "la", "pólvora"],
    ["descubr*", "la", "tostada"],
    ["dese*", "lo", "mejor"],
    ["desengaño", "amoroso"],
    ["desenlace", "fatal"],
    ["desenterr*", "el", "hacha", "de", "guerra"],
    ["deseo", "ferviente"],
    ["deshielo", "entre", "dos", "países"],
    ["deshiz*", "en", "elogios", "hacia"],
    ["deshoj*", "la", "margarita"],
    ["desnud*", "el", "alma"],
    ["despach*", "a", "gusto"],
    ["despacito", "y", "buena", "letra"],
    ["desped*", "a", "la", "francesa"],
    ["despert*", "inquietud"],
    ["despido", "fulminante"],
    ["desplome", "de", "la", "bolsa"],
    ["destap*", "la", "caja", "de", "los", "truenos"],
    ["destru*", "empleo"],
    ["desvelando", "ningún", "secreto"],
    ["devaluación", "competitiva", "de", "los", "salarios"],
    ["devolv*", "la", "conexión"],
    ["devolv*", "la", "pelota"],
    ["diamante", "en", "bruto"],
    ["diametralmente", "opuesto"],
    ["dices", "o", "me", "lo", "cuentas"],
    ["dicho", "esto"],
    ["dicho", "y", "hecho"],
    ["diestro", "y", "siniestro"],
    ["dilatada", "experiencia"],
    ["dilatada", "trayectoria"],
    ["dimes", "y", "diretes"],
    ["dinamit*", "un", "acuerdo"],
    ["dinero", "contante", "y", "sonante"],
    ["dio", "pie"],
    ["dios", "nos", "pille", "confesados"],
    ["dios", "reparta", "suerte"],
    ["dios", "te", "conserve", "la", "vista"],
    ["dios", "te", "oiga"],
    ["directo", "al", "matadero"],
    ["dirig*", "el", "cotarro"],
    ["discreto", "segundo", "plano"],
    ["discusión", "bizantina"],
    ["disfrut*", "como", "un", "enano"],
    ["disfrut*", "de", "lo", "lindo"],
    ["dispar*", "los", "precios"],
    ["disparo", "envenenado"],
    ["distingu*", "las", "churras", "de", "las", "merinas"],
    ["divide", "y", "vencerás"],
    ["división", "de", "opiniones"],
    ["diálogo", "de", "besugos"],
    ["doble", "o", "nada"],
    ["doctores", "tiene", "la", "iglesia"],
    ["dolor", "indescriptible"],
    ["dolor", "insoportable"],
    ["domin*", "la", "situación"],
    ["don", "de", "lenguas"],
    ["don", "nadie"],
    ["donde", "caben", "dos", "caben", "tres"],
    ["donde", "comen", "dos", "comen", "tres"],
    ["donde", "dios", "no", "quiso", "ir"],
    ["donde", "duermen", "las", "arañas"],
    ["donde", "hay", "patrón", "no", "manda", "marinero"],
    ["donde", "la", "espalda", "pierde", "su", "casto", "nombre"],
    ["donde", "las", "dan", "las", "toman"],
    ["donde", "no", "le", "llaman"],
    ["dor*", "la", "píldora"],
    ["dos", "caras", "de", "la", "moneda"],
    ["dos", "dedos", "de", "frente"],
    ["dos", "pájaros", "de", "un", "tiro"],
    ["dos", "sin", "tres"],
    ["dramáticos", "momentos"],
    ["duda", "ofende"],
    ["duelo", "de", "titanes"],
    ["dulce", "derrota"],
    ["dur*", "más", "que", "un", "martillo", "en", "manteca"],
    ["duro", "correctivo"],
    ["duro", "de", "mollera"],
    ["duro", "que", "la", "pata", "perico"],
    ["duro", "que", "una", "piedra"],
    ["duros", "a", "cuatro", "pesetas"],
    ["día", "de", "perros"],
    ["día", "histórico"],
    ["día", "negro"],
    ["día", "señalado"],
    ["día", "sí", "otro", "también"],
    ["día", "sí", "y", "otro", "también"],
    ["ech*", "a", "perder"],
    ["ech*", "balones", "fuera"],
    ["ech*", "cara"],
    ["ech*", "con", "cajas", "destempladas"],
    ["ech*", "el", "cerrojo", "atrás"],
    ["ech*", "el", "freno"],
    ["ech*", "el", "resto"],
    ["ech*", "flores"],
    ["ech*", "guindas", "al", "pavo"],
    ["ech*", "humo"],
    ["ech*", "la", "pota"],
    ["ech*", "las", "campanas", "al", "vuelo"],
    ["ech*", "las", "cuentas", "de", "la", "lechera"],
    ["ech*", "leña", "al", "fuego"],
    ["ech*", "mal", "de", "ojo"],
    ["ech*", "margaritas", "a", "los", "cerdos"],
    ["ech*", "más", "leña", "al", "fuego"],
    ["ech*", "pestes"],
    ["ech*", "por", "tierra"],
    ["ech*", "raíces"],
    ["ech*", "sapos", "y", "culebras"],
    ["ech*", "teatro"],
    ["ech*", "un", "cable"],
    ["ech*", "un", "capote"],
    ["ech*", "un", "galgo"],
    ["ech*", "un", "polvo"],
    ["ech*", "un", "pulso"],
    ["ech*", "un", "rapapolvo"],
    ["ech*", "un", "vistazo"],
    ["ech*", "un", "órdago"],
    ["ech*", "una", "cana", "al", "aire"],
    ["ech*", "una", "mano"],
    ["ech*", "unas", "risas"],
    ["echa", "el", "freno", "magdaleno"],
    ["echado", "para", "adelante"],
    ["echando", "leches"],
    ["echarle", "de", "comer", "aparte"],
    ["economía", "se", "ralentiza"],
    ["edad", "del", "pavo"],
    ["efectivos", "de", "la", "policía"],
    ["efectu*", "disparos"],
    ["el", "abrazo", "del", "oso"],
    ["el", "alma", "en", "vilo"],
    ["el", "amor", "es", "ciego"],
    ["el", "autodenominado", "estado", "islámico"],
    ["el", "año", "de", "la", "polca"],
    ["el", "baile", "de", "san", "vito"],
    ["el", "canto", "de", "un", "duro"],
    ["el", "canto", "del", "cisne"],
    ["el", "capitán", "araña"],
    ["el", "carro", "antes", "de", "los", "bueyes"],
    ["el", "centro", "de", "todas", "las", "miradas"],
    ["el", "cielo", "abierto"],
    ["el", "cielo", "ganado"],
    ["el", "colmo"],
    ["el", "conjunto", "ché"],
    ["el", "conjunto", "colchonero"],
    ["el", "conjunto", "merengue"],
    ["el", "contagio", "de", "la", "deuda"],
    ["el", "contagio", "de", "los", "mercados"],
    ["el", "corazón", "en", "un", "puño"],
    ["el", "cuento", "de", "la", "lechera"],
    ["el", "cuento", "de", "nunca", "acabar"],
    ["el", "cuerpo", "me", "pide"],
    ["el", "de", "marras"],
    ["el", "dedo", "en", "la", "llaga"],
    ["el", "deporte", "rey"],
    ["el", "día", "d"],
    ["el", "día", "de", "mañana"],
    ["el", "día", "menos", "pensado"],
    ["el", "dólar", "se", "desploma"],
    ["el", "equipo", "cae", "ante", "el"],
    ["el", "equipo", "de", "sus", "amores"],
    ["el", "equipo", "pierde", "y", "se", "descuelga", "en", "la", "tabla"],
    ["el", "esférico"],
    ["el", "españolito", "de", "a", "pie"],
    ["el", "espíritu", "navideño"],
    ["el", "estadio", "se", "vino", "abajo"],
    ["el", "fantasma", "del", "descenso"],
    ["el", "fantasma", "del", "paro"],
    ["el", "flagelo", "de", "la", "droga"],
    ["el", "flamante", "auto"],
    ["el", "futuro", "está", "por", "venir"],
    ["el", "garbanzo", "negro", "de", "la", "familia"],
    ["el", "gato", "al", "agua"],
    ["el", "gordo", "ha", "caído", "íntegramente"],
    ["el", "grifo", "del", "dinero"],
    ["el", "hambre", "con", "las", "ganas", "de", "comer"],
    ["el", "hecho", "fue", "perpetrado"],
    ["el", "horno", "para", "bollos"],
    ["el", "huevo", "de", "colón"],
    ["el", "inquilino", "de", "la", "casa", "blanca"],
    ["el", "inquilino", "de", "la", "moncloa"],
    ["el", "lado", "humano"],
    ["el", "lirio", "en", "la", "mano"],
    ["el", "lucero", "del", "alba"],
    ["el", "lugar", "de", "los", "hechos"],
    ["el", "malo", "de", "la", "película"],
    ["el", "malogrado", "individuo"],
    ["el", "mercurio", "se", "dispara"],
    ["el", "mismo", "que", "viste", "y", "calza"],
    ["el", "movimiento", "se", "demuestra", "andando"],
    ["el", "mundo", "encima"],
    ["el", "mundo", "es", "un", "pañuelo"],
    ["el", "mundo", "por", "montera"],
    ["el", "no", "va", "más"],
    ["el", "oro", "y", "el", "moro"],
    ["el", "pan", "nuestro", "de", "cada", "día"],
    ["el", "papel", "lo", "aguanta", "todo"],
    ["el", "partido", "del", "siglo"],
    ["el", "pasado", "ya", "es", "historia"],
    ["el", "patito", "feo"],
    ["el", "país", "vecino"],
    ["el", "pelotón", "de", "los", "torpes"],
    ["el", "peso", "político"],
    ["el", "protagonista"],
    ["el", "pulso", "a", "la", "actualidad"],
    ["el", "punto", "álgido"],
    ["el", "que", "avisa", "no", "es", "traidor"],
    ["el", "que", "no", "corre", "vuela"],
    ["el", "que", "se", "pica", "ajos", "come"],
    ["el", "quid", "de", "la", "cuestión"],
    ["el", "rabillo", "del", "ojo"],
    ["el", "resultado", "ha", "deparado", "sorpresas"],
    ["el", "saldo", "total", "de", "víctimas", "se", "eleva", "a"],
    ["el", "santo", "al", "cielo"],
    ["el", "secreto", "mejor", "guardado"],
    ["el", "siniestro", "se", "inició"],
    ["el", "tamaño", "no", "importa"],
    ["el", "todo", "por", "el", "todo"],
    ["el", "truco", "del", "almendruco"],
    ["el", "vello", "de", "punta"],
    ["el", "vital", "líquido"],
    ["el", "último", "mono"],
    ["eleg*", "a", "dedo"],
    ["elemento", "estás", "hecho"],
    ["emotivas", "imágenes"],
    ["empanada", "mental"],
    ["empap*", "de", "algo"],
    ["empez*", "con", "buen", "pie"],
    ["empez*", "con", "el", "pie", "izquierdo"],
    ["empez*", "de", "cero"],
    ["empez*", "de", "nuevo"],
    ["empez*", "la", "casa", "por", "el", "tejado"],
    ["empin*", "el", "codo"],
    ["en", "ascuas"],
    ["en", "babia"],
    ["en", "base", "a"],
    ["en", "breves", "minutos", "momentos"],
    ["en", "buenas", "manos"],
    ["en", "busca", "y", "captura"],
    ["en", "consideración", "todos", "los", "factores"],
    ["en", "cuerpo", "y", "alma"],
    ["en", "dique", "seco"],
    ["en", "efecto"],
    ["en", "el", "candelero"],
    ["en", "el", "coche", "de", "san", "fernando"],
    ["en", "el", "marco", "de"],
    ["en", "el", "mejor", "de", "los", "casos"],
    ["en", "el", "mejor", "de", "los", "sentidos"],
    ["en", "el", "mejor", "sentido", "de", "la", "palabra"],
    ["en", "el", "ojo", "del", "huracán"],
    ["en", "el", "plano", "informativo"],
    ["en", "el", "punto", "de", "mira"],
    ["en", "el", "quinto", "pino"],
    ["en", "el", "radar"],
    ["en", "el", "último", "suspiro"],
    ["en", "esta", "fecha", "tan", "señalada"],
    ["en", "esta", "sociedad", "en", "la", "que", "nos", "ha", "tocado", "vivir"],
    ["en", "este", "mismo", "instante"],
    ["en", "estricto", "rigor"],
    ["en", "horas", "bajas"],
    ["en", "la", "boca", "del", "lobo"],
    ["en", "la", "cresta", "de", "la", "ola"],
    ["en", "la", "cuerda", "floja"],
    ["en", "la", "flor", "de", "la", "vida"],
    ["en", "la", "gloria"],
    ["en", "la", "inopia"],
    ["en", "la", "luna"],
    ["en", "la", "más", "estricta", "intimidad"],
    ["en", "la", "onda"],
    ["en", "la", "punta", "de", "la", "lengua"],
    ["en", "las", "nubes"],
    ["en", "las", "últimas"],
    ["en", "letras", "de", "molde"],
    ["en", "los", "brazos", "de", "morfeo"],
    ["en", "los", "zapatos", "de", "otro"],
    ["en", "menos", "que", "canta", "un", "gallo"],
    ["en", "mi", "peor", "pesadilla"],
    ["en", "mis", "mejores", "sueños"],
    ["en", "olor", "de", "multitudes"],
    ["en", "otro", "orden", "de", "cosas"],
    ["en", "paz", "descanse"],
    ["en", "plan"],
    ["en", "plena", "vía", "pública"],
    ["en", "resumidas", "cuentas"],
    ["en", "riguroso", "directo"],
    ["en", "román", "paladino"],
    ["en", "su", "sano", "juicio"],
    ["en", "sus", "cabales"],
    ["en", "sus", "trece"],
    ["en", "tiempos", "de", "maricastaña"],
    ["en", "toda", "regla"],
    ["en", "todas", "partes", "cuecen", "habas"],
    ["en", "un", "abrir", "y", "cerrar", "de", "ojos"],
    ["en", "un", "atolladero"],
    ["en", "un", "callejón", "sin", "salida"],
    ["en", "un", "día", "como", "hoy"],
    ["en", "un", "periquete"],
    ["en", "un", "pispás"],
    ["en", "un", "plis", "plas"],
    ["en", "un", "santiamén"],
    ["en", "un", "sinvivir"],
    ["en", "un", "tris"],
    ["en", "un", "visto", "y", "no", "visto"],
    ["en", "vivo", "y", "en", "directo"],
    ["encaje", "de", "bolillos"],
    ["encasquet*", "el", "bulto"],
    ["encend*", "todas", "las", "alarmas"],
    ["encontr*", "la", "horma", "de", "su", "zapato"],
    ["encontr*", "una", "aguja", "en", "un", "paj*"],
    ["enderez*", "el", "rumbo"],
    ["endeud*", "hasta", "las", "cejas"],
    ["endos*", "el", "muerto"],
    ["enemigo", "público", "número", "uno"],
    ["enfri*", "el", "ambiente"],
    ["enfri*", "los", "mercados"],
    ["enfund*", "la", "elástica"],
    ["engañ*", "como", "a", "un", "chino"],
    ["engord*", "para", "morir"],
    ["enmend*", "la", "plana"],
    ["enroll*", "como", "una", "persiana"],
    ["enseñ*", "el", "cobre"],
    ["enseñ*", "los", "dientes"],
    ["ent*", "ni", "jota"],
    ["ent*", "ni", "papa"],
    ["enton*", "el", "mea", "culpa"],
    ["entr*", "a", "mat*"],
    ["entr*", "al", "trapo"],
    ["entr*", "como", "un", "elefante", "en", "una", "cacharrería"],
    ["entr*", "con", "buen", "pie"],
    ["entr*", "con", "calzador"],
    ["entr*", "con", "mal", "pie"],
    ["entr*", "de", "gorra"],
    ["entr*", "en", "bucle"],
    ["entr*", "en", "escena"],
    ["entr*", "en", "pánico"],
    ["entr*", "en", "vereda"],
    ["entr*", "en", "vía", "muerta"],
    ["entr*", "por", "el", "ojo", "derecho"],
    ["entr*", "por", "la", "puerta", "de", "atrás"],
    ["entr*", "por", "un", "oído", "y", "salir", "por", "el", "otro"],
    ["entrad?", "en", "años"],
    ["entrad?", "en", "carnes"],
    ["entre", "algodones"],
    ["entre", "bastidores"],
    ["entre", "ceja", "y", "ceja"],
    ["entre", "comillas"],
    ["entre", "la", "espada", "y", "la", "pared"],
    ["entre", "los", "tres", "palos"],
    ["entre", "pinto", "y", "valdemoro"],
    ["entre", "pitos", "y", "flautas"],
    ["entrenamiento", "a", "puerta", "cerrada"],
    ["entro", "col", "y", "col", "lechuga"],
    ["envain*", "la", "espada"],
    ["envid*", "a", "pares"],
    ["enérgica", "repulsa"],
    ["epicentro", "de"],
    ["er*", "mi", "ídolo"],
    ["err*", "es", "humano"],
    ["erre", "que", "erre"],
    ["error", "garrafal"],
    ["es", "de", "cajón"],
    ["es", "lo", "que", "hay"],
    ["es", "profeta", "en", "su", "tierra"],
    ["es", "una", "noticia", "en", "desarrollo"],
    ["esboz*", "una", "sonrisa"],
    ["escalada", "de", "violencia"],
    ["escaquearse", "de", "algo"],
    ["escarment*", "en", "cabeza", "ajena"],
    ["escen*", "dantesca"],
    ["escen*", "de", "profundo", "dramatismo"],
    ["escenific*", "algo"],
    ["esconder", "la", "cabeza", "debajo", "del", "ala"],
    ["escribir", "más", "que", "el", "tostado"],
    ["escrito", "en", "la", "frente"],
    ["escudo", "humano"],
    ["escup*", "el", "dinero"],
    ["escup*", "por", "el", "colmillo"],
    ["escurr*", "el", "bulto"],
    ["esfuerzo", "encomiable"],
    ["eso", "es", "música", "celestial"],
    ["eso", "no", "lo", "compro"],
    ["eso", "no", "lo", "siguiente"],
    ["eso", "que", "lo", "haga", "rita"],
    ["eso", "son", "palabras", "mayores"],
    ["espada", "de", "damocles"],
    ["espada", "de", "dos", "filos"],
    ["espadas", "siguen", "en", "alto"],
    ["espectaculares", "imágenes"],
    ["espectáculo", "dantesco"],
    ["esper*", "el", "santo", "advenimiento"],
    ["espiral", "de", "violencia"],
    ["est*", "a", "la", "cuarta", "pregunta"],
    ["est*", "a", "la", "defensiva"],
    ["est*", "a", "la", "espera", "de"],
    ["est*", "a", "la", "que", "cae"],
    ["est*", "a", "verlas", "venir"],
    ["est*", "al", "caer"],
    ["est*", "alicaído"],
    ["est*", "aplatanado"],
    ["est*", "atacado", "de", "los", "nervios"],
    ["est*", "atado", "de", "pies", "y", "manos"],
    ["est*", "bajo", "control"],
    ["est*", "bajo", "mínimos"],
    ["est*", "bien", "empleado"],
    ["est*", "cantado"],
    ["est*", "cascado"],
    ["est*", "causando", "sensación"],
    ["est*", "chocheando"],
    ["est*", "claro", "como", "el", "agua"],
    ["est*", "cogido", "con", "alfileres"],
    ["est*", "cogido", "con", "pinzas"],
    ["est*", "colgado"],
    ["est*", "como", "una", "cabra"],
    ["est*", "como", "una", "chota"],
    ["est*", "como", "una", "mesa", "camilla"],
    ["est*", "como", "unas", "castañuelas"],
    ["est*", "comprado"],
    ["est*", "con", "la", "antena", "puesta"],
    ["est*", "con", "una", "mano", "delante", "y", "otra", "detrás"],
    ["est*", "cuadrado"],
    ["est*", "curado", "de", "espanto"],
    ["est*", "de", "bajón"],
    ["est*", "de", "buen", "ver"],
    ["est*", "de", "capa", "caída"],
    ["est*", "de", "fábula"],
    ["est*", "de", "morros"],
    ["est*", "de", "rodríguez"],
    ["est*", "de", "vuelta"],
    ["est*", "dejado", "de", "la", "mano", "de", "dios"],
    ["est*", "desaparecido", "en", "combate"],
    ["est*", "echando", "humo"],
    ["est*", "empanado"],
    ["est*", "empantanado"],
    ["est*", "en", "barbecho"],
    ["est*", "en", "boca", "de", "todos"],
    ["est*", "en", "buen", "plan"],
    ["est*", "en", "cuarentena"],
    ["est*", "en", "el", "aire"],
    ["est*", "en", "el", "ajo"],
    ["est*", "en", "el", "culo", "del", "mundo"],
    ["est*", "en", "el", "dique", "seco"],
    ["est*", "en", "el", "mismo", "barco"],
    ["est*", "en", "el", "séptimo", "cielo"],
    ["est*", "en", "entredicho"],
    ["est*", "en", "la", "conchinchina"],
    ["est*", "en", "la", "edad", "del", "pavo"],
    ["est*", "en", "la", "inopia"],
    ["est*", "en", "la", "lista", "negra"],
    ["est*", "en", "la", "pomada"],
    ["est*", "en", "los", "huesos"],
    ["est*", "en", "medio", "como", "el", "jueves"],
    ["est*", "en", "misa", "y", "repicando"],
    ["est*", "en", "pañales"],
    ["est*", "en", "paños", "menores"],
    ["est*", "en", "pelotas"],
    ["est*", "en", "sintonía", "con"],
    ["est*", "en", "su", "casa"],
    ["est*", "en", "un", "ay"],
    ["est*", "en", "un", "tris"],
    ["est*", "enchufado"],
    ["est*", "encima", "de", "la", "mesa"],
    ["est*", "endeudado", "hasta", "las", "cejas"],
    ["est*", "enganchado"],
    ["est*", "entre", "dos", "fuegos"],
    ["est*", "entre", "rejas"],
    ["est*", "frito"],
    ["est*", "fuera", "de", "juego"],
    ["est*", "grogui"],
    ["est*", "hasta", "las", "cejas"],
    ["est*", "hasta", "las", "pelotas"],
    ["est*", "hasta", "los", "topes"],
    ["est*", "hecho", "de", "otra", "pasta"],
    ["est*", "hecho", "polvo"],
    ["est*", "hecho", "un", "flan"],
    ["est*", "hecho", "un", "guiñapo"],
    ["est*", "hecho", "un", "judas"],
    ["est*", "hecho", "un", "roble"],
    ["est*", "hecho", "un", "trapo"],
    ["est*", "hecho", "un", "vendo"],
    ["est*", "hecho", "una", "sílfide"],
    ["est*", "hecho", "unos", "zorros"],
    ["est*", "ko"],
    ["est*", "la", "pelota", "en", "su", "tejado"],
    ["est*", "limpio", "de", "polvo", "y", "paja"],
    ["est*", "mano", "sobre", "mano"],
    ["est*", "mejor", "que", "en", "brazos"],
    ["est*", "más", "ancho", "que", "largo"],
    ["est*", "más", "liado", "que", "la", "pata", "de", "un", "romano"],
    ["est*", "más", "perdido", "que", "un", "pulpo", "en", "un", "garaje"],
    ["est*", "más", "p’allá", "que", "p’acá"],
    ["est*", "más", "sano", "que", "una", "manzana"],
    ["est*", "más", "sordo", "que", "una", "tapia"],
    ["est*", "para", "chuparse", "los", "dedos"],
    ["est*", "para", "el", "arrastre"],
    ["est*", "para", "estos", "trotes"],
    ["est*", "pelao"],
    ["est*", "pez"],
    ["est*", "pillando", "moscas"],
    ["est*", "piripi"],
    ["est*", "podrido", "de", "dinero"],
    ["est*", "por", "la", "labor"],
    ["est*", "por", "las", "nubes"],
    ["est*", "por", "los", "suelos"],
    ["est*", "que", "echa", "chispas"],
    ["est*", "que", "trina"],
    ["est*", "quemado"],
    ["est*", "salido"],
    ["est*", "sembrado"],
    ["est*", "sin", "blanca"],
    ["est*", "sin", "oficio", "ni", "beneficio"],
    ["est*", "sobrado"],
    ["est*", "sonado"],
    ["est*", "tieso"],
    ["est*", "tocado"],
    ["est*", "vendido"],
    ["est*", "verde", "en", "un"],
    ["est*", "vivito", "y", "coleando"],
    ["est*", "zombi"],
    ["estable", "dentro", "de", "su", "gravedad"],
    ["este", "es", "un", "momento", "histórico"],
    ["este", "viaje", "no", "hacían", "falta", "alforjas"],
    ["estir*", "la", "pata"],
    ["estir*", "las", "piernas"],
    ["estir*", "un", "poco"],
    ["esto", "es", "así", "y", "punto"],
    ["esto", "es", "jauja"],
    ["esto", "es", "tela", "de", "grande"],
    ["esto", "ha", "sido", "todo"],
    ["esto", "no", "hay", "quien", "lo", "aguante"],
    ["esto", "no", "viene", "a", "cuento"],
    ["esto", "se", "lleva", "la", "palma"],
    ["esto", "va", "a", "misa"],
    ["estrech*", "el", "margen"],
    ["estrecha", "colaboración"],
    ["estremecedor", "relato"],
    ["estrujarse", "los", "sesos"],
    ["está", "que", "arde"],
    ["estómago", "a", "prueba", "de", "bombas"],
    ["evit*", "la", "tentación"],
    ["excepción", "que", "confirma", "la", "regla"],
    ["excesiva", "familiaridad"],
    ["excrementos", "caninos"],
    ["experiencia", "es", "la", "madre", "de", "la", "ciencia"],
    ["experiencia", "es", "un", "grado"],
    ["experimentos", "con", "gaseosa"],
    ["explicarse", "como", "un", "libro", "abierto"],
    ["exprimido", "como", "un", "limón"],
    ["fall*", "más", "que", "una", "escopeta", "de", "feria"],
    ["fallo", "clamoroso"],
    ["falt*", "a", "la", "verdad"],
    ["falt*", "el", "canto", "de", "un", "duro"],
    ["faltarle", "chispa"],
    ["faltarle", "un", "hervor"],
    ["faltarle", "un", "tornillo"],
    ["farolillo", "rojo"],
    ["fe", "del", "carbonero"],
    ["feas", "las", "cosas"],
    ["feliz", "como", "una", "perdiz"],
    ["feo", "que", "picio"],
    ["fi*", "ni", "un", "pelo"],
    ["fiel", "reflejo"],
    ["fiesta", "de", "la", "democracia"],
    ["fijo", "que", "a", "lo", "mejor"],
    ["final", "de", "infarto"],
    ["finolis"],
    ["flexibiliz*", "el", "mercado", "laboral"],
    ["flip*", "en", "colores"],
    ["flor", "de", "piel"],
    ["flor", "de", "un", "día"],
    ["flor", "y", "nata"],
    ["form*", "parte", "del", "adn"],
    ["forz*", "la", "máquina"],
    ["fren*", "en", "seco"],
    ["frot*", "las", "manos"],
    ["frustr*", "las", "esperanzas"],
    ["fruto", "de", "la", "casualidad"],
    ["fría", "realidad"],
    ["frío", "como", "el", "mármol"],
    ["frío", "como", "un", "témpano"],
    ["frío", "que", "pela"],
    ["fuente", "inagotable"],
    ["fuentes", "bien", "informadas"],
    ["fuentes", "cercanas", "a"],
    ["fuentes", "de", "su", "entorno"],
    ["fuentes", "de", "toda", "solvencia"],
    ["fuera", "de", "combate"],
    ["fuera", "de", "onda"],
    ["fuera", "de", "serie"],
    ["fueron", "los", "encargados", "de"],
    ["fuerte", "deflagración"],
    ["fuertemente", "armados"],
    ["fuerzas", "de", "flaqueza"],
    ["fulmin*", "con", "la", "mirada"],
    ["fum*", "como", "un", "carretero"],
    ["fum*", "como", "una", "chimenea"],
    ["fum*", "en", "pipa"],
    ["fum*", "la", "pipa", "de", "la", "paz"],
    ["fum*", "un", "puro"],
    ["fum*", "una", "clase"],
    ["fumata", "blanca"],
    ["funcion*", "como", "un", "reloj"],
    ["fund*", "en", "un", "abrazo"],
    ["fund*", "la", "pasta"],
    ["fund*", "los", "plomos"],
    ["fusil*", "un", "texto"],
    ["futuro", "de", "color", "de", "rosa"],
    ["futuro", "incierto"],
    ["gallina", "de", "los", "huevos", "de", "oro"],
    ["gan*", "a", "pulso"],
    ["gan*", "dinero", "a", "espuertas"],
    ["gan*", "las", "habichuelas"],
    ["gan*", "para", "disgustos"],
    ["gan*", "para", "sustos"],
    ["gan*", "peso"],
    ["gan*", "por", "goleada"],
    ["gan*", "por", "la", "mano"],
    ["gan*", "por", "la", "mínima"],
    ["gan*", "sin", "despeinarse"],
    ["gan*", "una", "pasta", "gansa"],
    ["gato", "encerrado"],
    ["gener*", "sinergias"],
    ["generaciones", "venideras"],
    ["gente", "de", "a", "pie"],
    ["gente", "de", "bien"],
    ["gente", "para", "todo"],
    ["gestos", "ostensibles"],
    ["gigante", "con", "pies", "de", "barro"],
    ["giro", "de", "180", "grados"],
    ["giro", "inesperado"],
    ["gol", "del", "honor"],
    ["gol", "psicológico"],
    ["golpe", "de", "efecto"],
    ["golpe", "de", "suerte"],
    ["golpe", "de", "talonario"],
    ["golpe", "de", "vista"],
    ["gota", "que", "colma", "el", "vaso"],
    ["goz*", "como", "un", "enano"],
    ["gozo", "en", "un", "pozo"],
    ["grab*", "a", "fuego"],
    ["gran", "expectación", "mediática"],
    ["grit*", "a", "viva", "voz"],
    ["griterío", "ensordecedor"],
    ["grito", "en", "el", "cielo"],
    ["grito", "pelado"],
    ["guard*", "bajo", "llave"],
    ["guard*", "cama"],
    ["guard*", "las", "distancias"],
    ["guard*", "las", "espaldas"],
    ["guardarlo", "como", "oro", "en", "paño"],
    ["guardarse", "un", "as", "en", "la", "manga"],
    ["guerra", "sin", "cuartel"],
    ["guinda", "del", "pastel"],
    ["gust*", "ni", "un", "pelo"],
    ["gust*", "un", "pelo"],
    ["h*", "a", "regañadientes"],
    ["h*", "como", "quien", "no", "quiere", "la", "cosa"],
    ["h*", "de", "extranjis"],
    ["h*", "de", "la", "necesidad", "virtud"],
    ["h*", "de", "oro"],
    ["h*", "de", "su", "capa", "un", "sayo"],
    ["h*", "de", "tripas", "corazón"],
    ["h*", "eco", "de", "una", "noticia"],
    ["h*", "el", "agosto"],
    ["h*", "el", "cabra"],
    ["h*", "el", "caldo", "gordo"],
    ["h*", "el", "chorra"],
    ["h*", "el", "ganso"],
    ["h*", "el", "harakiri"],
    ["h*", "el", "indio"],
    ["h*", "el", "loco"],
    ["h*", "el", "longui"],
    ["h*", "el", "paripé"],
    ["h*", "el", "payaso"],
    ["h*", "el", "primo"],
    ["h*", "el", "propósito", "de", "la", "enmienda"],
    ["h*", "el", "remolón"],
    ["h*", "el", "sordo"],
    ["h*", "el", "sueco"],
    ["h*", "el", "vacío"],
    ["h*", "encaje", "de", "bolillos"],
    ["h*", "eterno"],
    ["h*", "gala", "de"],
    ["h*", "hincapié"],
    ["h*", "la", "13", "14"],
    ["h*", "la", "boca", "agua"],
    ["h*", "la", "cama"],
    ["h*", "la", "cobra"],
    ["h*", "la", "estatua"],
    ["h*", "la", "guerra", "por", "su", "cuenta"],
    ["h*", "la", "jarrita"],
    ["h*", "la", "pascua"],
    ["h*", "la", "peineta"],
    ["h*", "la", "pelota"],
    ["h*", "la", "pinza"],
    ["h*", "la", "pirula"],
    ["h*", "la", "sangre"],
    ["h*", "la", "vista", "gorda"],
    ["h*", "la", "víctima"],
    ["h*", "las", "delicias", "de", "chicos", "y", "grandes"],
    ["h*", "las", "delicias", "de"],
    ["h*", "las", "maletas"],
    ["h*", "leña", "del", "árbol", "caído"],
    ["h*", "lo", "propio"],
    ["h*", "los", "deberes"],
    ["h*", "los", "sentimientos"],
    ["h*", "mala", "sangre"],
    ["h*", "morder", "el", "ajo"],
    ["h*", "mutis", "por", "el", "foro"],
    ["h*", "méritos"],
    ["h*", "números"],
    ["h*", "oídos", "sordos"],
    ["h*", "palmas", "con", "las", "orejas"],
    ["h*", "papilla"],
    ["h*", "pasar", "por", "el", "aro"],
    ["h*", "pellas"],
    ["h*", "perrerías"],
    ["h*", "piña"],
    ["h*", "por", "las", "buenas", "o", "por", "las", "malas"],
    ["h*", "pupa"],
    ["h*", "puré"],
    ["h*", "puñetas"],
    ["h*", "saltar", "chispas"],
    ["h*", "saltar", "todas", "las", "alarmas"],
    ["h*", "sombra"],
    ["h*", "sus", "necesidades"],
    ["h*", "sus", "pinitos"],
    ["h*", "susceptibilidades"],
    ["h*", "tabla", "rasa"],
    ["h*", "tilín"],
    ["h*", "trampas", "al", "solitario"],
    ["h*", "un", "apaño"],
    ["h*", "un", "calvo"],
    ["h*", "un", "ejercicio", "de"],
    ["h*", "un", "feo"],
    ["h*", "un", "flaco", "favor"],
    ["h*", "un", "hueco"],
    ["h*", "un", "lavado", "de", "cara"],
    ["h*", "un", "mundo", "de"],
    ["h*", "un", "paradón"],
    ["h*", "una", "de", "las", "suyas"],
    ["h*", "una", "faena"],
    ["h*", "una", "montaña", "de", "un", "grano", "de", "arena"],
    ["h*", "valer", "el", "resultado"],
    ["ha", "comido", "la", "lengua", "el", "gato"],
    ["ha", "dicho", "un", "pajarito"],
    ["ha", "estado", "muy", "repartido"],
    ["ha", "llegado", "para", "quedarse"],
    ["ha", "llovido", "mucho", "desde", "entonces"],
    ["ha", "nacido", "una", "estrella"],
    ["ha", "tenido", "que", "sufrir", "para", "ganar"],
    ["ha", "venido", "para", "quedarse"],
    ["hab*", "hecho", "los", "deberes"],
    ["hab*", "hecho", "mucha", "mili"],
    ["hab*", "moros", "en", "la", "costa"],
    ["habl*", "con", "las", "paredes"],
    ["habl*", "con", "segundas"],
    ["habl*", "en", "chino"],
    ["habl*", "en", "cristiano"],
    ["habl*", "en", "plata"],
    ["habl*", "más", "que", "un", "sacamuelas"],
    ["habl*", "por", "boca", "de", "ganso"],
    ["habl*", "por", "habl*"],
    ["habl*", "por", "los", "codos"],
    ["hablan", "las", "urnas"],
    ["hablando", "del", "rey", "de", "roma"],
    ["hac*", "a", "regañadientes"],
    ["hac*", "aguas"],
    ["hac*", "buenas", "migas"],
    ["hac*", "caso", "omiso"],
    ["hac*", "castillos", "de", "arena"],
    ["hac*", "castillos", "en", "el", "aire"],
    ["hambre", "de", "triunfos"],
    ["hambre", "que", "un", "maestro", "de", "escuela"],
    ["harina", "de", "otro", "costal"],
    ["hasta", "altas", "horas", "de", "la", "madrugada"],
    ["hasta", "aquí", "hemos", "llegado"],
    ["hasta", "aquí", "podíamos", "llegar"],
    ["hasta", "aquí", "puedo", "leer"],
    ["hasta", "decir", "basta"],
    ["hasta", "donde", "alcanza", "la", "vista"],
    ["hasta", "el", "gorro"],
    ["hasta", "el", "moño"],
    ["hasta", "el", "rabo", "todo", "es", "toro"],
    ["hasta", "el", "último", "aliento"],
    ["hasta", "la", "bandera"],
    ["hasta", "la", "coronilla"],
    ["hasta", "la", "médula"],
    ["hasta", "las", "cachas"],
    ["hasta", "las", "narices"],
    ["hasta", "las", "trancas"],
    ["hasta", "las", "últimas", "consecuencias"],
    ["hasta", "los", "topes"],
    ["hasta", "los", "tuétanos"],
    ["hasta", "luego", "lucas"],
    ["hasta", "que", "la", "muerte", "nos", "separe"],
    ["hay", "ropa", "tendida"],
    ["hay", "tomate"],
    ["he", "hecho", "yo", "para", "merecer", "esto"],
    ["hech?", "polvo"],
    ["hech?", "trizas"],
    ["hech?", "un", "basilisco"],
    ["hech?", "un", "figurín"],
    ["hech?", "un", "pincel"],
    ["hech?", "un", "toro"],
    ["hecho", "horripilante"],
    ["hecho", "un", "adefesio"],
    ["hecho", "un", "adán"],
    ["hecho", "un", "basilisco"],
    ["hecho", "un", "cristo"],
    ["hecho", "una", "fiera"],
    ["hecho", "una", "furia"],
    ["hecho", "una", "sopa"],
    ["hechos", "hablan", "por", "sí", "solos"],
    ["hechos", "son", "elocuentes"],
    ["heridas", "de", "diversa", "consideración"],
    ["heridos", "de", "pronóstico", "reservado"],
    ["hermanita", "de", "la", "caridad"],
    ["herrar", "o", "quitar", "el", "banco"],
    ["hijo", "de", "su", "tiempo"],
    ["hil*", "fino"],
    ["hil*", "muy", "fino"],
    ["hinc*", "la", "uña"],
    ["hinc*", "los", "codos"],
    ["hincarle", "el", "diente"],
    ["hinch*", "el", "perro"],
    ["hinchársele", "las", "narices"],
    ["hoja", "de", "ruta"],
    ["hombre", "de", "paja"],
    ["hombre", "de", "pelo", "en", "pecho"],
    ["hombre", "de", "provecho"],
    ["hombre", "hecho", "a", "sí", "mismo"],
    ["hombre", "hecho", "y", "derecho"],
    ["hora", "de", "la", "verdad"],
    ["hora", "punta"],
    ["horchata", "en", "las", "venas"],
    ["horma", "de", "tu", "zapato"],
    ["hoy", "en", "día"],
    ["hoy", "no", "es", "mi", "día"],
    ["hoy", "por", "hoy"],
    ["hoy", "por", "ti", "mañana", "por", "mí"],
    ["hu*", "como", "de", "la", "peste"],
    ["huele", "a", "chamusquina"],
    ["hueso", "de", "la", "risa"],
    ["hueso", "duro", "de", "roer"],
    ["humor", "de", "perros"],
    ["hund*", "en", "el", "fango"],
    ["hurg*", "en", "la", "herida"],
    ["idea", "peregrina"],
    ["ideas", "de", "bombero"],
    ["ideas", "que", "vertebran"],
    ["imagen", "espectacular"],
    ["imagen", "vale", "más", "que", "mil", "palabras"],
    ["imperdonable", "error"],
    ["importa", "un", "bledo"],
    ["importa", "un", "comino"],
    ["importa", "un", "pepino"],
    ["importa", "un", "pimiento"],
    ["importa", "un", "rábano"],
    ["importante", "hallazgo"],
    ["imágenes", "hablan", "por", "sí", "solas"],
    ["imágenes", "son", "bien", "elocuentes"],
    ["in", "albis"],
    ["in", "extremis"],
    ["incendio", "pavoroso"],
    ["inclemencias", "del", "tiempo"],
    ["incompatibilidad", "de", "caracteres"],
    ["indiferente", "a", "nadie"],
    ["inexorable", "paso", "del", "tiempo"],
    ["infl*", "las", "narices"],
    ["inocencia", "perdida"],
    ["inoportuna", "lesión"],
    ["insospechadas", "consecuencias"],
    ["instinto", "asesino"],
    ["insulto", "a", "la", "inteligencia"],
    ["intensas", "lluvias"],
    ["intenso", "operativo"],
    ["invent*", "la", "pólvora"],
    ["invitado", "de", "postín"],
    ["inyect*", "liquidez"],
    ["irreparable", "pérdida"],
    ["isla", "paradisíaca"],
    ["jamás", "de", "los", "jamases"],
    ["jarro", "de", "agua", "fría"],
    ["jaula", "de", "grillos"],
    ["jod*", "el", "invento"],
    ["jornada", "maratoniana"],
    ["jornada", "transcurrió", "con", "normalidad"],
    ["jornada", "transcurrió", "sin", "incidentes"],
    ["joya", "de", "la", "corona"],
    ["juego", "de", "niños"],
    ["jug*", "a", "dos", "bandas"],
    ["jug*", "a", "medio", "gas"],
    ["jug*", "bien", "sus", "cartas"],
    ["jug*", "con", "dos", "barajas"],
    ["jug*", "con", "fuego"],
    ["jug*", "el", "pellejo"],
    ["jug*", "el", "tipo"],
    ["jug*", "en", "otra", "liga"],
    ["jug*", "la", "vida"],
    ["jug*", "los", "cuartos"],
    ["jug*", "una", "mala", "pasada"],
    ["juguete", "roto"],
    ["jur*", "en", "arameo"],
    ["justo", "vencedor"],
    ["la", "alegría", "de", "la", "casa"],
    ["la", "alegría", "de", "la", "huerta"],
    ["la", "arcadia", "feliz"],
    ["la", "artillería", "pesada"],
    ["la", "balanza", "a", "su", "favor"],
    ["la", "biblia", "en", "verso"],
    ["la", "carne", "en", "el", "asador"],
    ["la", "cepa", "del", "poste"],
    ["la", "codiciada", "estatuilla"],
    ["la", "fiesta", "en", "paz"],
    ["la", "friolera", "de"],
    ["la", "fuerza", "por", "la", "boca"],
    ["la", "gente", "se", "agolpa"],
    ["la", "justicia", "por", "su", "mano"],
    ["la", "ley", "a", "la", "torera"],
    ["la", "luz", "al", "final", "del", "túnel"],
    ["la", "media", "naranja"],
    ["la", "más", "remota", "idea"],
    ["la", "niña", "de", "sus", "ojos"],
    ["la", "o", "con", "un", "canuto"],
    ["la", "paja", "en", "el", "ojo", "ajeno"],
    ["la", "peña"],
    ["la", "piel", "de", "gallina"],
    ["la", "sartén", "por", "el", "mango"],
    ["la", "soga", "en", "casa", "del", "ahorcado"],
    ["la", "vieja", "escuela"],
    ["la", "voz", "cantante"],
    ["labr*", "un", "buen", "futuro"],
    ["lacra", "de", "la", "sociedad"],
    ["lacra", "de", "la", "violencia", "de", "género"],
    ["ladr*", "a", "la", "luna"],
    ["ladrón", "de", "guante", "blanco"],
    ["lam*", "las", "heridas"],
    ["lament*", "los", "hechos"],
    ["lamentar", "víctimas"],
    ["lanz*", "las", "campanas", "al", "vuelo"],
    ["lanz*", "un", "dardo", "envenenado"],
    ["lanz*", "un", "misil"],
    ["lanz*", "un", "torpedo"],
    ["lanz*", "un", "órdago"],
    ["lanz*", "una", "indirecta"],
    ["lanza", "en", "ristre"],
    ["lanzarse", "al", "ruedo"],
    ["larga", "y", "dura", "enfermedad"],
    ["larga", "y", "penosa", "enfermedad"],
    ["largo", "etcétera"],
    ["largo", "que", "un", "día", "sin", "pan"],
    ["largo", "y", "tendido"],
    ["largos", "años"],
    ["largos", "minutos"],
    ["largos", "segundos"],
    ["las", "castañas", "del", "fuego"],
    ["las", "comparaciones", "son", "odiosas"],
    ["las", "de", "perder"],
    ["las", "horas", "contadas"],
    ["las", "mieles", "del", "éxito"],
    ["las", "musarañas"],
    ["las", "narices", "donde", "no", "te", "llaman"],
    ["las", "orejas", "al", "lobo"],
    ["lav*", "el", "cerebro"],
    ["le", "hace", "sombra"],
    ["le", "vamos", "a", "hacer"],
    ["le*", "entre", "líneas"],
    ["le*", "la", "cartilla"],
    ["le*", "la", "jugada"],
    ["le*", "la", "letra", "pequeña"],
    ["lento", "que", "el", "caballo", "del", "malo"],
    ["letra", "pequeña"],
    ["levant*", "ampollas"],
    ["levant*", "con", "el", "pie", "izquierdo"],
    ["levant*", "con", "mal", "pie"],
    ["levant*", "el", "campamento"],
    ["ley", "del", "embudo"],
    ["leyenda", "urbana"],
    ["leña", "al", "mono", "que", "es", "de", "goma"],
    ["li*", "el", "petate"],
    ["li*", "la", "de", "dios"],
    ["li*", "la", "manta", "a", "la", "cabeza"],
    ["lidi*", "con", "un", "problema"],
    ["lim*", "asperezas"],
    ["limpi*", "de", "polvo", "y", "paja"],
    ["limpieza", "étnica"],
    ["limpio", "que", "una", "patena"],
    ["lisa", "y", "llanamente"],
    ["lista", "negra"],
    ["listo", "que", "el", "hambre"],
    ["listón", "muy", "alto"],
    ["llam*", "a", "la", "cuestión"],
    ["llam*", "a", "la", "puerta"],
    ["llam*", "al", "orden"],
    ["lleg*", "a", "buen", "puerto"],
    ["lleg*", "a", "fin", "de", "mes"],
    ["lleg*", "a", "la", "cima"],
    ["lleg*", "a", "las", "manos"],
    ["lleg*", "a", "los", "quioscos"],
    ["lleg*", "a", "mesa", "puesta"],
    ["lleg*", "con", "una", "copa", "de", "más"],
    ["lleg*", "para", "quedarse"],
    ["lleg*", "y", "bes*", "el", "santo"],
    ["llegados", "a", "este", "punto"],
    ["llen*", "la", "cabeza", "de", "humo"],
    ["llen*", "la", "cabeza", "de", "pájaros"],
    ["llenarse", "la", "boca", "de"],
    ["lleno", "a", "rebosar"],
    ["llev*", "a", "matar"],
    ["llev*", "a", "su", "terreno"],
    ["llev*", "al", "huerto"],
    ["llev*", "con", "alfileres"],
    ["llev*", "el", "agua", "a", "su", "molino"],
    ["llev*", "en", "palmitas"],
    ["llev*", "en", "volandas"],
    ["llev*", "la", "batuta"],
    ["llev*", "un", "chasco"],
    ["llev*", "un", "secreto", "a", "la", "tumba"],
    ["llorar", "a", "lágrima", "viva"],
    ["llorar", "a", "moco", "tendido"],
    ["llorar", "como", "una", "magdalena"],
    ["llorar", "por", "las", "esquinas"],
    ["llover", "a", "cántaros"],
    ["llover", "a", "mares"],
    ["llover", "sobre", "mojado"],
    ["lluvia", "de", "goles"],
    ["lluvia", "de", "millones"],
    ["lo", "cierto", "es", "que"],
    ["lo", "nunca", "visto"],
    ["lo", "primero", "decir", "que"],
    ["lo", "que", "es", "de", "agradecer"],
    ["lo", "que", "hay", "que", "oír"],
    ["lo", "que", "no", "está", "escrito"],
    ["lo", "que", "no", "mata", "engorda"],
    ["lo", "que", "te", "rondaré", "morena"],
    ["lo", "que", "tenía", "que", "pasar"],
    ["lo", "que", "vale", "un", "peine"],
    ["lo", "que", "viene", "siendo"],
    ["lobo", "con", "piel", "de", "cordero"],
    ["loca", "carrera"],
    ["loco", "de", "atar"],
    ["loco", "de", "remate"],
    ["locomotora", "de", "la", "economía"],
    ["los", "deberes", "hechos"],
    ["los", "días", "contados"],
    ["los", "pies", "de", "barro"],
    ["los", "riesgos", "del", "directo"],
    ["los", "tiempos", "que", "corren"],
    ["los", "toros", "desde", "la", "barrera"],
    ["los", "trapos", "sucios", "se", "lavan", "en", "casa"],
    ["los", "últimos", "de", "filipinas"],
    ["lotería", "de", "los", "penaltis"],
    ["luc*", "palmito"],
    ["luces", "y", "sombras"],
    ["lucha", "encarnizada"],
    ["lujo", "asiático"],
    ["lágrimas", "de", "cocodrilo"],
    ["líneas", "rojas"],
    ["lío", "de", "faldas"],
    ["líquido", "elemento"],
    ["m[ou]r*", "como", "chinches"],
    ["m[ou]r*", "con", "las", "botas", "puestas"],
    ["m[ou]r*", "de", "aburrimiento"],
    ["m[ou]r*", "de", "asco"],
    ["m[ou]r*", "de", "frío"],
    ["m[ou]r*", "de", "ganas"],
    ["m[ou]r*", "de", "hambre"],
    ["m[ou]r*", "de", "risa"],
    ["m[ou]r*", "de", "sueño"],
    ["m[ou]r*", "de", "éxito"],
    ["m[ou]r*", "en", "el", "intento"],
    ["m[ou]r*", "hasta", "el", "apuntador"],
    ["m[ou]v*", "el", "bigote"],
    ["m[ou]v*", "el", "esqueleto"],
    ["m[ou]v*", "ficha"],
    ["m[ou]v*", "la", "silla"],
    ["m[ou]v*", "los", "hilos"],
    ["macabro", "crimen"],
    ["macabro", "hallazgo"],
    ["madre", "de", "todas", "las"],
    ["madre", "no", "hay", "más", "que", "una"],
    ["madre", "que", "te", "parió"],
    ["majara", "perdido"],
    ["majo", "que", "las", "pesetas"],
    ["mal", "rayo", "te", "parta"],
    ["mala", "baba"],
    ["mala", "hierba", "nunca", "muere"],
    ["mala", "pinta"],
    ["mala", "sombra"],
    ["malas", "lenguas"],
    ["mand*", "a", "paseo"],
    ["mand*", "al", "otro", "barrio"],
    ["manda", "huevos"],
    ["manej*", "con", "soltura"],
    ["manej*", "el", "cotarro"],
    ["manga", "por", "hombro"],
    ["mano", "de", "hierro"],
    ["mano", "de", "santo"],
    ["mano", "dura"],
    ["mano", "sobre", "mano"],
    ["manojo", "de", "nervios"],
    ["manos", "a", "la", "obra"],
    ["manos", "de", "mantequilla"],
    ["manten*", "a", "flote"],
    ["manten*", "el", "equilibrio"],
    ["manten*", "en", "sus", "trece"],
    ["manten*", "la", "boca", "cerrada"],
    ["manten*", "las", "distancias"],
    ["mantente", "mientras", "cobro"],
    ["manzana", "de", "la", "discordia"],
    ["manzana", "podrida"],
    ["maquill*", "el", "resultado"],
    ["maquin*", "un", "plan"],
    ["maquinaria", "electoral"],
    ["marc*", "distancias"],
    ["marc*", "el", "ritmo"],
    ["marc*", "el", "rumbo"],
    ["marc*", "los", "tiempos"],
    ["marc*", "un", "farol"],
    ["marc*", "un", "tanto"],
    ["marca", "de", "la", "casa"],
    ["marcaje", "férreo"],
    ["marco", "incomparable"],
    ["mare*", "la", "perdiz"],
    ["mariposas", "en", "el", "estómago"],
    ["masa", "crítica"],
    ["mascarse", "la", "tragedia"],
    ["masiva", "concurrencia"],
    ["masiva", "participación"],
    ["mat*", "al", "mensajero"],
    ["mat*", "el", "gusanillo"],
    ["mat*", "el", "hambre"],
    ["mat*", "el", "tiempo"],
    ["mat*", "ni", "una", "mosca"],
    ["matarlas", "callando"],
    ["matrimonio", "de", "conveniencia"],
    ["mañana", "más"],
    ["mañana", "será", "otro", "día"],
    ["me", "da", "corte"],
    ["me", "da", "fatiga"],
    ["me", "da", "la", "gana"],
    ["me", "estás", "vacilando"],
    ["me", "la", "refanfinfla"],
    ["me", "la", "repanfinfla"],
    ["me", "la", "suda"],
    ["me", "la", "trae", "al", "pairo"],
    ["me", "la", "trae", "floja"],
    ["me", "sabe", "mal"],
    ["me", "suena", "bien"],
    ["me", "temo", "lo", "peor"],
    ["me", "vengas", "con", "milongas"],
    ["mear", "fuera", "del", "tiesto"],
    ["medias", "tintas"],
    ["medidas", "drásticas"],
    ["medio", "en", "broma", "medio", "en", "serio"],
    ["medir", "las", "palabras"],
    ["mejor", "defensa", "es", "un", "buen", "ataque"],
    ["mejorcito", "de", "cada", "casa"],
    ["mejores", "raquetas"],
    ["menos", "da", "una", "piedra"],
    ["menos", "lobos", "caperucita"],
    ["menos", "que", "un", "gato", "de", "escayola"],
    ["mensaje", "claro", "y", "contundente"],
    ["mensaje", "inequívoco"],
    ["mentar", "la", "bicha"],
    ["mentir", "como", "un", "bellaco"],
    ["mentira", "cochina"],
    ["mentira", "piadosa"],
    ["menuda", "noche", "la", "de", "aquel", "día"],
    ["menudo", "pájaro"],
    ["mercados", "se", "desploman"],
    ["merecer", "un", "capítulo", "aparte"],
    ["merecidas", "vacaciones"],
    ["merecido", "descanso"],
    ["merend*", "al", "rival"],
    ["merienda", "de", "negros"],
    ["mero", "espectador"],
    ["meros", "espectadores"],
    ["met*", "a", "farolero"],
    ["met*", "a", "redentor"],
    ["met*", "baza"],
    ["met*", "cizaña"],
    ["met*", "con", "calzador"],
    ["met*", "de", "hoz", "y", "coz"],
    ["met*", "de", "lleno"],
    ["met*", "donde", "no", "le", "importa"],
    ["met*", "el", "dedo", "en", "el", "ojo"],
    ["met*", "en", "chirona"],
    ["met*", "en", "cintura"],
    ["met*", "en", "el", "bolsillo"],
    ["met*", "en", "el", "mismo", "saco"],
    ["met*", "en", "el", "pellejo"],
    ["met*", "en", "el", "talego"],
    ["met*", "en", "harina"],
    ["met*", "en", "la", "boca", "del", "lobo"],
    ["met*", "en", "todos", "los", "embolados"],
    ["met*", "en", "un", "berenjenal"],
    ["met*", "en", "un", "callejón", "sin", "salida"],
    ["met*", "en", "un", "charco"],
    ["met*", "en", "un", "jaleo"],
    ["met*", "en", "un", "jardín"],
    ["met*", "en", "un", "lío"],
    ["met*", "en", "vereda"],
    ["met*", "la", "cuchara"],
    ["met*", "la", "directa"],
    ["met*", "la", "gamba"],
    ["met*", "la", "mano", "en", "el", "cajón"],
    ["met*", "la", "pata"],
    ["met*", "la", "quinta", "marcha"],
    ["met*", "un", "batacazo"],
    ["met*", "un", "paquete"],
    ["met*", "una", "pulla"],
    ["meteórico", "ascenso"],
    ["mide", "tus", "palabras"],
    ["miel", "sobre", "hojuelas"],
    ["miente", "más", "que", "habla"],
    ["mientras", "el", "cuerpo", "aguante"],
    ["mientras", "revisamos", "las", "imágenes"],
    ["millonetis"],
    ["minutos", "de", "terror"],
    ["mir*", "a", "la", "cara"],
    ["mir*", "al", "tendido"],
    ["mir*", "con", "lupa"],
    ["mir*", "el", "ombligo"],
    ["mira", "que", "te", "lo", "tengo", "dicho"],
    ["mira", "quién", "baila"],
    ["miradas", "que", "matan"],
    ["mis", "más", "sinceras", "condolencias"],
    ["mismo", "da", "que", "da", "lo", "mismo"],
    ["mismos", "perros", "con", "distintos", "collares"],
    ["moco", "de", "pavo"],
    ["moderación", "salarial"],
    ["modestia", "aparte"],
    ["moj*", "el", "culo"],
    ["moj*", "por", "algo"],
    ["mojarle", "la", "oreja"],
    ["mol*", "a", "palos"],
    ["mond*", "de", "la", "risa"],
    ["monos", "en", "la", "cara"],
    ["mont*", "de", "cine"],
    ["mont*", "en", "cólera"],
    ["mont*", "un", "circo"],
    ["mont*", "un", "cirio"],
    ["mont*", "un", "numerito"],
    ["mont*", "un", "plan"],
    ["mont*", "un", "pollo"],
    ["mont*", "un", "sarao"],
    ["mont*", "un", "show"],
    ["mont*", "un", "tinglado"],
    ["mont*", "una", "escena"],
    ["mont*", "una", "película"],
    ["montaje", "mediático"],
    ["mord*", "el", "anzuelo"],
    ["mord*", "el", "polvo"],
    ["mord*", "la", "lengua"],
    ["moros", "en", "la", "costa"],
    ["mortal", "de", "necesidad"],
    ["moscas", "a", "cañonazos"],
    ["mosquita", "muerta"],
    ["mostrar", "su", "peor", "versión"],
    ["movilidad", "exterior"],
    ["mucha", "correa"],
    ["mucha", "jeta"],
    ["mucha", "labia"],
    ["mucha", "marcha"],
    ["mucha", "mili"],
    ["mucha", "pegada"],
    ["muchas", "opciones", "de", "gol"],
    ["muchas", "tablas"],
    ["muchas", "ínfulas"],
    ["mucho", "ojito"],
    ["mucho", "rollo"],
    ["muchos", "humos"],
    ["muerto", "de", "hambre"],
    ["mujer", "explosiva"],
    ["mujer", "florero"],
    ["multitudinario", "adiós"],
    ["muro", "infranqueable"],
    ["mutismo", "absoluto"],
    ["más", "cara", "que", "espalda"],
    ["más", "caro", "que", "un", "hijo", "tonto"],
    ["más", "claro", "agua"],
    ["más", "de", "la", "cuenta"],
    ["más", "distinguida", "consideración"],
    ["más", "días", "que", "longanizas"],
    ["más", "fe", "que", "el", "alcoyano"],
    ["más", "largo", "que", "ancho"],
    ["más", "moral", "que", "el", "alcoyano"],
    ["más", "paciencia", "que", "el", "santo", "job"],
    ["más", "razón", "que", "un", "santo"],
    ["más", "se", "perdió", "en", "cuba"],
    ["más", "te", "valdría", "no", "haber", "nacido"],
    ["más", "tonto", "porque", "no", "te", "entrenas"],
    ["más", "tonto", "que", "hecho", "de", "encargo"],
    ["más", "vidas", "que", "un", "gato"],
    ["más", "viejo", "que", "matusalén"],
    ["más", "viejos", "del", "lugar"],
    ["más", "íntimos", "secretos"],
    ["máxima", "expectación"],
    ["mírame", "y", "no", "me", "toques"],
    ["módico", "precio"],
    ["móvil", "sentimental"],
    ["músculo", "financiero"],
    ["música", "maestro"],
    ["nac*", "de", "pie"],
    ["nad*", "en", "la", "abundancia"],
    ["nad*", "entre", "dos", "aguas"],
    ["nad*", "y", "guard*", "la", "ropa"],
    ["nada", "del", "otro", "jueves"],
    ["nada", "del", "otro", "mundo"],
    ["nada", "despreciable", "cantidad"],
    ["nada", "en", "el", "tintero"],
    ["nada", "más", "lejos", "de", "la", "realidad"],
    ["nada", "nuevo", "bajo", "el", "sol"],
    ["nada", "por", "sentado"],
    ["nadie", "lo", "diría"],
    ["naranjas", "de", "la", "china"],
    ["negar", "la", "mayor"],
    ["negocio", "redondo"],
    ["negro", "que", "el", "betún", "el", "carbón"],
    ["nervios", "a", "flor", "de", "piel"],
    ["ni", "a", "la", "de", "tres"],
    ["ni", "a", "la", "suela", "de", "los", "zapatos"],
    ["ni", "a", "sol", "ni", "a", "sombra"],
    ["ni", "borracho"],
    ["ni", "del", "nodo"],
    ["ni", "el", "apuntador"],
    ["ni", "el", "tato"],
    ["ni", "en", "pintura"],
    ["ni", "en", "sueños"],
    ["ni", "esta", "boca", "es", "mía"],
    ["ni", "freír", "un", "huevo"],
    ["ni", "fu", "ni", "fa"],
    ["ni", "hablar", "del", "peluquín"],
    ["ni", "harto", "de", "vino"],
    ["ni", "mu"],
    ["ni", "más", "ni", "menos"],
    ["ni", "para", "pipas"],
    ["ni", "para", "ti", "ni", "para", "mí"],
    ["ni", "pies", "ni", "cabeza"],
    ["ni", "pizca", "de", "gracia"],
    ["ni", "por", "asomo"],
    ["ni", "pío"],
    ["ni", "qué", "decir", "tiene"],
    ["ni", "qué", "niño", "muerto"],
    ["ni", "qué", "ocho", "cuartos"],
    ["ni", "siquiera", "hace", "falta", "que", "lo", "digas"],
    ["ni", "un", "pelo", "de", "tonto"],
    ["nieve", "copiosa"],
    ["no", "*", "trigo", "limpio"],
    ["no", "admite", "interpretación"],
    ["no", "d*", "abasto"],
    ["no", "d*", "la", "talla"],
    ["no", "d*", "más", "de", "sí"],
    ["no", "d*", "ni", "golpe"],
    ["no", "d*", "ni", "los", "buenos", "días"],
    ["no", "d*", "ni", "un", "duro"],
    ["no", "d*", "ni", "una"],
    ["no", "d*", "tregua"],
    ["no", "eres", "tú", "soy", "yo"],
    ["no", "es", "un", "dato", "menor"],
    ["no", "es", "un", "tema", "menor"],
    ["no", "est*", "muy", "católico"],
    ["no", "est*", "para", "bromas"],
    ["no", "est*", "para", "fiestas"],
    ["no", "est*", "para", "tirar", "cohetes"],
    ["no", "h*", "nacido", "ayer"],
    ["no", "h*", "roto", "un", "plato"],
    ["no", "ha", "nacido", "el", "guapo", "que"],
    ["no", "ha*", "nada", "a", "derechas"],
    ["no", "ha*", "ni", "el", "huevo"],
    ["no", "ha*", "ni", "huevo"],
    ["no", "ha*", "prob*", "bocado"],
    ["no", "hay", "enemigo", "pequeño"],
    ["no", "hay", "libro", "tan", "malo", "que", "no", "tenga", "algo", "bueno"],
    ["no", "hay", "más", "cera", "que", "la", "que", "arde"],
    ["no", "hay", "que", "descartar", "que"],
    ["no", "hay", "quien", "me", "tosa"],
    ["no", "hay", "quinto", "malo"],
    ["no", "hay", "tiempo", "para", "más"],
    ["no", "hay", "tutía"],
    ["no", "l[eoa]", "quit*", "ojo", "de", "encima"],
    ["no", "le", "llega", "la", "camisa", "al", "cuerpo"],
    ["no", "lo", "entiende", "ni", "dios"],
    ["no", "lo", "siguiente"],
    ["no", "me", "cuentes", "cuentos"],
    ["no", "me", "cuentes", "milongas"],
    ["no", "me", "cuentes", "tu", "vida"],
    ["no", "me", "digas"],
    ["no", "me", "quita", "el", "sueño"],
    ["no", "me", "salen", "las", "cuentas"],
    ["no", "mov*", "un", "dedo"],
    ["no", "perd*", "comba"],
    ["no", "perd*", "ripio"],
    ["no", "pill*", "comba"],
    ["no", "pint*", "bien"],
    ["no", "pint*", "nada"],
    ["no", "por", "ello", "menos", "importante"],
    ["no", "presagi*", "nada", "bueno"],
    ["no", "prob*", "bocado"],
    ["no", "pudo", "ser"],
    ["no", "qued*", "otra", "que"],
    ["no", "quit*", "ojo", "de", "encima"],
    ["no", "s*", "de", "piedra"],
    ["no", "s*", "hermanitas", "de", "la", "caridad"],
    ["no", "sab*", "dónde", "meterse"],
    ["no", "sab*", "ni", "jota"],
    ["no", "se", "dignó", "acudir"],
    ["no", "se", "hable", "más"],
    ["no", "se", "oía", "ni", "una", "mosca"],
    ["no", "se", "va", "a", "comer", "el", "turrón"],
    ["no", "solt*", "prenda"],
    ["no", "solt*", "un", "duro"],
    ["no", "somos", "nada"],
    ["no", "t*", "abuela"],
    ["no", "t*", "cuerpo", "para"],
    ["no", "t*", "desperdicio"],
    ["no", "t*", "donde", "caerse", "muerto"],
    ["no", "t*", "sangre", "en", "las", "venas"],
    ["no", "t*", "vuelta", "atrás"],
    ["no", "t*", "vuelta", "de", "hoja"],
    ["no", "te", "lo", "crees", "ni", "tú"],
    ["no", "te", "quepa", "la", "menor", "duda"],
    ["no", "te", "sulfures"],
    ["no", "tiene", "pérdida"],
    ["no", "tiene", "remedio"],
    ["no", "tiene*", "perdón", "de", "dios"],
    ["no", "v*", "a", "cuento"],
    ["no", "val*", "un", "pimiento"],
    ["nota", "discordante"],
    ["nube", "de", "fotógrafos"],
    ["nudo", "gordiano"],
    ["nunca", "digas", "nunca", "jamás"],
    ["número", "indeterminado"],
    ["obr*", "el", "milagro"],
    ["obras", "dialogan", "entre", "sí"],
    ["ocasion*", "molestias"],
    ["ocasión", "de", "oro"],
    ["ocasión", "la", "pintan", "calva"],
    ["oficio", "ni", "beneficio"],
    ["ojo", "a", "la", "funerala"],
    ["ojo", "al", "cristo", "que", "es", "de", "plata"],
    ["ojo", "al", "dato"],
    ["ojo", "avizor"],
    ["ojo", "clínico"],
    ["ojos", "como", "platos"],
    ["ojos", "de", "cordero", "degollado"],
    ["ola", "de", "calor"],
    ["ola", "de", "robos"],
    ["oler", "a", "chamusquina"],
    ["oler", "a", "cuerno", "quemado"],
    ["oler", "a", "humanidad"],
    ["oler", "a", "tigre"],
    ["oler[ms]e", "la", "tostada"],
    ["olla", "a", "presión"],
    ["ombligo", "del", "mundo"],
    ["operación", "bikini"],
    ["operación", "retorno"],
    ["operación", "selectiva"],
    ["operado", "con", "éxito"],
    ["oportunidad", "desaprovechada"],
    ["opípara", "comida"],
    ["orejas", "de", "soplillo"],
    ["oro", "todo", "lo", "que", "reluce"],
    ["otra", "cara", "de", "la", "moneda"],
    ["otro", "cantar"],
    ["otro", "gallo", "cantaría"],
    ["otro", "que", "tal", "baila"],
    ["ovación", "cerrada"],
    ["oveja", "descarriada"],
    ["oveja", "negra"],
    ["oído", "cocina"],
    ["p[uo]*", "a", "mil"],
    ["p[uo]*", "a", "tiro"],
    ["p[uo]*", "el", "cascabel", "al", "gato"],
    ["p[uo]*", "en", "bandeja"],
    ["p[uo]*", "en", "jaque"],
    ["p[uo]*", "en", "la", "picota"],
    ["p[uo]*", "en", "la", "piel", "de"],
    ["p[uo]*", "en", "su", "sitio"],
    ["p[uo]*", "en", "tela", "de", "juicio"],
    ["p[uo]*", "en", "un", "brete"],
    ["p[uo]*", "encima", "de", "la", "mesa"],
    ["p[uo]*", "la", "carne", "de", "gallina"],
    ["p[uo]*", "la", "guinda", "en", "el", "pastel"],
    ["p[uo]*", "la", "mano", "en", "el", "fuego"],
    ["p[uo]*", "la", "otra", "mejilla"],
    ["p[uo]*", "la", "primera", "piedra"],
    ["p[uo]*", "la", "venda", "antes", "que", "la", "herida"],
    ["p[uo]*", "la", "venda", "en", "los", "ojos"],
    ["p[uo]*", "las", "barbas", "a", "remojar"],
    ["p[uo]*", "las", "botas"],
    ["p[uo]*", "las", "cartas", "sobre", "la", "mesa"],
    ["p[uo]*", "las", "cosas", "en", "su", "sitio"],
    ["p[uo]*", "las", "peras", "al", "cuarto"],
    ["p[uo]*", "las", "pilas"],
    ["p[uo]*", "los", "cinco", "sentidos"],
    ["p[uo]*", "los", "cuernos"],
    ["p[uo]*", "los", "dientes", "largos"],
    ["p[uo]*", "los", "pelos", "como", "escarpias"],
    ["p[uo]*", "los", "pelos", "de", "punta"],
    ["p[uo]*", "los", "puntos", "sobre", "las", "íes"],
    ["p[uo]*", "mala", "cara"],
    ["p[uo]*", "negro", "sobre", "blanco"],
    ["p[uo]*", "ojitos"],
    ["p[uo]*", "paños", "calientes"],
    ["p[uo]*", "pies", "en", "polvorosa"],
    ["p[uo]*", "puertas", "al", "campo"],
    ["p[uo]*", "punto", "y", "final"],
    ["paciencia", "y", "barajar"],
    ["paco", "con", "las", "rebajas"],
    ["pact*", "una", "tregua"],
    ["padres", "de", "la", "patria"],
    ["pag*", "a", "escote"],
    ["pag*", "a", "tocateja"],
    ["pag*", "con", "creces"],
    ["pag*", "con", "la", "misma", "moneda"],
    ["pag*", "el", "pato"],
    ["pag*", "en", "b"],
    ["pag*", "en", "dinero", "contante", "y", "sonante"],
    ["pag*", "en", "negro"],
    ["pag*", "justos", "por", "pecadores"],
    ["pag*", "los", "platos", "rotos"],
    ["pag*", "religiosamente"],
    ["palabras", "se", "quedan", "cortas"],
    ["palm*", "una", "pasta"],
    ["pan", "comido"],
    ["pan", "para", "tanto", "chorizo"],
    ["pandilla", "de", "descerebrados"],
    ["papel", "crucial"],
    ["papel", "mojado"],
    ["papista", "que", "el", "papa"],
    ["paquete", "de", "reformas"],
    ["para", "dar", "y", "regalar"],
    ["para", "el", "carro"],
    ["para", "gustos", "colores"],
    ["para", "muestra", "un", "botón"],
    ["para", "más", "inri"],
    ["para", "nadie", "es", "un", "secreto"],
    ["para", "parar", "un", "carro"],
    ["para", "parar", "un", "tren"],
    ["para", "rato"],
    ["para", "serte", "sincero"],
    ["para", "tapar", "agujeros"],
    ["para", "todos", "los", "gustos"],
    ["parar*", "en", "seco"],
    ["parar*", "los", "pies"],
    ["pare", "usted", "de", "contar"],
    ["parec*", "un", "disco", "rayado"],
    ["parece", "que", "fue", "ayer"],
    ["paredes", "oyen"],
    ["pareja", "sentimental"],
    ["part*", "de", "cero"],
    ["part*", "de", "la", "risa"],
    ["part*", "el", "alma"],
    ["part*", "el", "bacalao"],
    ["part*", "el", "corazón"],
    ["part*", "la", "cara"],
    ["part*", "la", "crisma"],
    ["part*", "la", "pana"],
    ["participación", "histórica"],
    ["paréntesis", "de", "la", "semana", "santa"],
    ["paréntesis", "veraniego"],
    ["pas*", "a", "la", "historia"],
    ["pas*", "a", "mayores"],
    ["pas*", "a", "mejor", "vida"],
    ["pas*", "al", "lado", "oscuro"],
    ["pas*", "canutas"],
    ["pas*", "de", "frenada"],
    ["pas*", "de", "la", "raya"],
    ["pas*", "de", "listo"],
    ["pas*", "de", "miedo"],
    ["pas*", "de", "puntillas", "sobre"],
    ["pas*", "de", "rosca"],
    ["pas*", "de", "todo"],
    ["pas*", "el", "rubicón"],
    ["pas*", "el", "testigo"],
    ["pas*", "factura"],
    ["pas*", "la", "garlopa"],
    ["pas*", "la", "noche", "en", "blanco"],
    ["pas*", "la", "noche", "en", "vela"],
    ["pas*", "la", "pelota", "a", "otro"],
    ["pas*", "la", "pelota"],
    ["pas*", "las", "de", "caín"],
    ["pas*", "olímpicamente"],
    ["pas*", "pipa"],
    ["pas*", "por", "alto"],
    ["pas*", "por", "chapa", "y", "pintura"],
    ["pas*", "por", "el", "aro"],
    ["pas*", "por", "encima"],
    ["pas*", "por", "la", "piedra"],
    ["pas*", "página"],
    ["pas*", "siete", "pueblos"],
    ["pas*", "sin", "pena", "ni", "gloria"],
    ["pas*", "un", "calvario"],
    ["pas*", "un", "mal", "rato"],
    ["pas*", "un", "mal", "trago"],
    ["pas*", "un", "pelo"],
    ["pas*", "una", "noche", "toledana"],
    ["pasado", "pasado", "está"],
    ["paso", "de", "gigante"],
    ["paso", "más", "allá"],
    ["pasto", "de", "las", "llamas"],
    ["patas", "arriba"],
    ["patas", "de", "gallo"],
    ["patata", "caliente"],
    ["patente", "de", "corso"],
    ["patitas", "en", "la", "calle"],
    ["paño", "de", "lágrimas"],
    ["peccata", "minuta"],
    ["pedazo", "de", "pan"],
    ["pedir", "peras", "al", "olmo"],
    ["peg*", "ni", "chapa"],
    ["peg*", "ni", "clavo"],
    ["peg*", "ni", "con", "cola"],
    ["peg*", "ni", "ojo"],
    ["peg*", "ni", "sello"],
    ["pein*", "canas"],
    ["pein*", "la", "zona"],
    ["pel*", "la", "pava"],
    ["pela", "es", "la", "pela"],
    ["pelea", "de", "gallos"],
    ["pelillos", "a", "la", "mar"],
    ["pelos", "en", "la", "lengua"],
    ["pena", "de", "telediario"],
    ["pend*", "de", "un", "hilo"],
    ["pensa*", "en", "las", "musarañas"],
    ["pensar", "a", "lo", "grande"],
    ["percha", "que", "es", "uno"],
    ["perd*", "comba"],
    ["perd*", "de", "vista"],
    ["perd*", "el", "contacto"],
    ["perd*", "el", "hilo"],
    ["perd*", "el", "juicio"],
    ["perd*", "el", "norte"],
    ["perd*", "el", "oremus"],
    ["perd*", "el", "rumbo"],
    ["perd*", "el", "tiempo"],
    ["perd*", "el", "tren"],
    ["perd*", "fuelle"],
    ["perd*", "la", "cabeza"],
    ["perd*", "la", "chaveta"],
    ["perd*", "la", "compostura"],
    ["perd*", "la", "dignidad"],
    ["perd*", "la", "fe"],
    ["perd*", "la", "paciencia"],
    ["perd*", "la", "pista"],
    ["perd*", "la", "vida"],
    ["perd*", "los", "estribos"],
    ["perd*", "los", "papeles"],
    ["perd*", "un", "tornillo"],
    ["perfil", "bajo"],
    ["pericia", "y", "sangre", "fría", "del", "piloto"],
    ["perico", "de", "los", "palotes"],
    ["perita", "en", "dulce"],
    ["perrito", "faldero"],
    ["pertinaz", "sequía"],
    ["pesar", "de", "los", "pesares"],
    ["pesca*", "a", "la", "primera"],
    ["pescadilla", "que", "se", "muerde", "la", "cola"],
    ["peso", "pesado"],
    ["petarlo"],
    ["pez", "grande", "se", "come", "al", "chico"],
    ["pez", "grande", "se", "come", "al", "pequeño"],
    ["pi[cq]*", "de", "oro"],
    ["pic*", "como", "un", "demonio"],
    ["pic*", "el", "anzuelo"],
    ["pic*", "el", "gusanillo"],
    ["pie", "con", "bola"],
    ["piedra", "en", "el", "zapato"],
    ["piedras", "contra", "su", "propio", "tejado"],
    ["pies", "para", "qué", "os", "quiero"],
    ["pill*", "con", "el", "pie", "cambiado"],
    ["pill*", "con", "las", "manos", "en", "la", "masa"],
    ["pill*", "en", "un", "renuncio"],
    ["pill*", "in", "fraganti"],
    ["pill*", "un", "catarro"],
    ["pinch*", "en", "hueso"],
    ["pincha", "ni", "corta"],
    ["pinta*", "bastos"],
    ["pinta*", "bien"],
    ["pis*", "en", "falso"],
    ["pis*", "los", "talones"],
    ["pisando", "fuerte"],
    ["pisando", "huevos"],
    ["pistoletazo", "de", "salida"],
    ["pitan", "los", "oídos"],
    ["plan", "maquiavélico"],
    ["plant*", "cara"],
    ["plant*", "un", "pino"],
    ["plena", "luz", "del", "día"],
    ["pobre", "diablo"],
    ["poco", "agraciado"],
    ["poderosamente", "la", "atención"],
    ["policía", "se", "personó"],
    ["polémica", "está", "servida"],
    ["políticamente", "correcto"],
    ["poquito", "de", "por", "favor"],
    ["por", "algo", "se", "empieza"],
    ["por", "amor", "al", "arte"],
    ["por", "arte", "de", "magia"],
    ["por", "buenos", "derroteros"],
    ["por", "doquier"],
    ["por", "dónde", "cogerlo"],
    ["por", "dónde", "le", "da", "el", "aire"],
    ["por", "el", "arco", "del", "triunfo"],
    ["por", "el", "mal", "camino"],
    ["por", "el", "pito", "del", "sereno"],
    ["por", "encima", "de", "sus", "posibilidades"],
    ["por", "encima", "del", "hombro"],
    ["por", "esa", "regla", "de", "tres"],
    ["por", "escaso", "margen"],
    ["por", "hache", "o", "por", "be"],
    ["por", "la", "cara"],
    ["por", "la", "cuenta", "que", "te", "trae"],
    ["por", "la", "patilla"],
    ["por", "la", "puerta", "grande"],
    ["por", "lana", "y", "salir", "trasquilado"],
    ["por", "las", "ramas"],
    ["por", "libre"],
    ["por", "lo", "bajini"],
    ["por", "los", "cerros", "de", "úbeda"],
    ["por", "los", "clavos", "de", "cristo"],
    ["por", "los", "pelos"],
    ["por", "peteneras"],
    ["por", "si", "suena", "la", "flauta"],
    ["por", "su", "mejor", "momento"],
    ["por", "tierra", "mar", "y", "aire"],
    ["por", "toda", "la", "geografía", "española"],
    ["por", "todo", "lo", "alto"],
    ["por", "todos", "sus", "poros"],
    ["por", "tu", "cara", "bonita"],
    ["por", "un", "oído", "y", "me", "sale", "por", "otro"],
    ["por", "un", "pelo"],
    ["por", "un", "tubo"],
    ["pozo", "sin", "fondo"],
    ["practic*", "la", "autopsia"],
    ["preciado", "líquido"],
    ["predic*", "a", "su", "parroquia"],
    ["predic*", "con", "el", "ejemplo"],
    ["predic*", "en", "el", "desierto"],
    ["prend*", "la", "mecha"],
    ["prepar*", "los", "bártulos"],
    ["present*", "batalla"],
    ["present*", "sus", "excusas"],
    ["presión", "mediática"],
    ["primer", "edil"],
    ["primera", "en", "la", "frente"],
    ["primera", "impresión", "es", "la", "que", "cuenta"],
    ["primeros", "compases"],
    ["prisas", "son", "malas", "consejeras"],
    ["prob*", "su", "propia", "medicina"],
    ["procesión", "va", "por", "dentro"],
    ["prometido", "es", "deuda"],
    ["pronto", "que", "tarde"],
    ["proporciones", "dantescas"],
    ["pudri*", "en", "la", "cárcel"],
    ["puerta", "siempre", "estará", "abierta"],
    ["puesta", "en", "escena"],
    ["pul*", "la", "pasta"],
    ["punta", "de", "lanza"],
    ["punta", "del", "iceberg"],
    ["puntada", "sin", "hilo"],
    ["punto", "de", "inflexión"],
    ["punto", "de", "no", "retorno"],
    ["punto", "en", "boca"],
    ["punto", "fatídico"],
    ["punto", "pelota"],
    ["punto", "y", "aparte"],
    ["pura", "realidad"],
    ["purga", "de", "benito"],
    ["puro", "y", "duro"],
    ["pájaros", "en", "la", "cabeza"],
    ["pólvora", "mojada"],
    ["que", "el", "mecanismo", "de", "un", "botijo"],
    ["que", "empiece", "la", "función"],
    ["que", "la", "suerte", "te", "acompañe"],
    ["que", "le", "zurzan"],
    ["que", "me", "quiten", "lo", "bailado"],
    ["que", "quita", "el", "hipo"],
    ["que", "risa", "tía", "felisa"],
    ["que", "sea", "lo", "que", "dios", "quiera"],
    ["que", "si", "patatín", "que", "si", "patatán"],
    ["que", "si", "quieres", "arroz", "catalina"],
    ["que", "te", "den", "dos", "duros"],
    ["que", "te", "den", "morcilla"],
    ["que", "te", "parta", "un", "rayo"],
    ["que", "te", "zurzan"],
    ["quebradero", "de", "cabeza"],
    ["qued*", "a", "cuadros"],
    ["qued*", "a", "la", "altura", "del", "betún"],
    ["qued*", "con", "el", "culo", "al", "aire"],
    ["qued*", "con", "las", "ganas"],
    ["qued*", "de", "brazos", "cruzados"],
    ["qued*", "de", "piedra"],
    ["qued*", "de", "una", "pieza"],
    ["qued*", "dos", "telediarios"],
    ["qued*", "en", "agua", "de", "borrajas"],
    ["qued*", "en", "blanco"],
    ["qued*", "en", "el", "tintero"],
    ["qued*", "en", "los", "huesos"],
    ["qued*", "encandilado"],
    ["qued*", "helado"],
    ["qued*", "más", "ancho", "que", "largo"],
    ["qued*", "más", "remedio"],
    ["qued*", "ni", "el", "apuntador"],
    ["qued*", "pajarito"],
    ["qued*", "para", "vestir", "santos"],
    ["qued*", "patidifuso"],
    ["qued*", "reducido", "a", "cenizas"],
    ["qued*", "roque"],
    ["qued*", "sin", "palabras"],
    ["qued*", "tan", "a", "gusto"],
    ["qued*", "tan", "fresco"],
    ["qued*", "tan", "pancho"],
    ["quedan", "los", "últimos", "flecos"],
    ["quem*", "el", "último", "cartucho"],
    ["quem*", "las", "naves"],
    ["quem*", "puentes"],
    ["querer", "es", "poder"],
    ["querer", "y", "no", "poder"],
    ["quien", "avisa", "no", "es", "traidor"],
    ["quien", "no", "te", "conozca", "que", "te", "compre"],
    ["quien", "se", "fue", "a", "sevilla", "perdió", "su", "silla"],
    ["quiero", "y", "no", "puedo"],
    ["quit*", "años", "de", "encima"],
    ["quit*", "de", "en", "medio"],
    ["quit*", "el", "hipo"],
    ["quit*", "el", "sombrero"],
    ["quit*", "la", "careta"],
    ["quit*", "la", "palabra", "de", "la", "boca"],
    ["quit*", "las", "ganas"],
    ["quit*", "un", "peso", "de", "encima"],
    ["quita*", "hierro"],
    ["quién", "lo", "iba", "a", "decir"],
    ["quién", "te", "ha", "dado", "vela", "en", "este", "entierro"],
    ["quién", "te", "ha", "visto", "y", "quién", "te", "ve"],
    ["quién", "te", "manda", "hacer", "eso"],
    ["qué", "cruz"],
    ["qué", "mosca", "te", "ha", "picado"],
    ["qué", "nivel"],
    ["qué", "quieres", "que", "te", "diga"],
    ["qué", "sé", "yo"],
    ["qué", "te", "dije", "yo"],
    ["química", "entre", "ellos"],
    ["quítame", "allá", "esas", "pajas"],
    ["rabiosa", "actualidad"],
    ["radio", "macuto"],
    ["radiografía", "del", "momento"],
    ["ramalazo", "de", "dolor"],
    ["raro", "que", "un", "perro", "verde"],
    ["rasc*", "el", "bolsillo"],
    ["rasc*", "la", "cartera"],
    ["rasg*", "las", "vestiduras"],
    ["ratón", "de", "biblioteca"],
    ["raudo", "y", "veloz"],
    ["reacciones", "no", "se", "han", "hecho", "esperar"],
    ["reacción", "en", "cadena"],
    ["reajuste", "de", "precios"],
    ["reban*", "el", "pescuezo"],
    ["recarg*", "las", "pilas"],
    ["recib*", "con", "los", "brazos", "abiertos"],
    ["recib*", "su", "recompensa"],
    ["recién", "salido", "del", "horno"],
    ["recog*", "el", "guante"],
    ["recog*", "los", "bártulos"],
    ["recta", "final"],
    ["reducido", "a", "cenizas"],
    ["refresc*", "la", "memoria"],
    ["regal*", "los", "oídos"],
    ["rei*", "de", "su", "sombra"],
    ["rei*", "por", "no", "llorar"],
    ["reina", "del", "suspense"],
    ["reinvent*", "la", "rueda"],
    ["relativa", "calma"],
    ["rem*", "en", "la", "misma", "dirección"],
    ["remat*", "a", "placer"],
    ["remat*", "la", "faena"],
    ["remat*", "la", "jugada"],
    ["remont*", "el", "vuelo"],
    ["remov*", "cielo", "y", "tierra"],
    ["remov*", "la", "conciencia"],
    ["remov*", "roma", "con", "santiago"],
    ["rend*", "a", "sus", "pies"],
    ["rendir", "homenaje"],
    ["repar*", "en", "gastos"],
    ["repart*", "el", "pastel"],
    ["repart*", "estopa"],
    ["reparto", "de", "puntos"],
    ["repet*", "hasta", "la", "saciedad"],
    ["repet*", "más", "que", "el", "ajo"],
    ["repet*", "más", "que", "un", "loro"],
    ["república", "bananera"],
    ["resolv*", "la", "papeleta"],
    ["respetable", "público"],
    ["rest*", "importancia"],
    ["restaur*", "el", "orden"],
    ["restreg*", "por", "las", "narices"],
    ["retirada", "a", "tiempo"],
    ["reunión", "en", "la", "cumbre"],
    ["revolv*", "en", "su", "tumba"],
    ["rey", "de", "la", "casa"],
    ["rey", "de", "la", "selva"],
    ["rey", "del", "mambo"],
    ["ridículo", "espantoso"],
    ["riguroso", "luto"],
    ["risa", "floja"],
    ["risa", "va", "por", "barrios"],
    ["risilla", "del", "conejo"],
    ["ritmo", "pegadizo"],
    ["riz*", "el", "rizo"],
    ["rob*", "el", "tiempo"],
    ["robarle", "la", "cartera"],
    ["rodar*", "cabezas"],
    ["rodead[oa]", "de", "los", "suyos"],
    ["romp*", "el", "corazón"],
    ["romp*", "el", "hechizo"],
    ["romp*", "el", "hielo"],
    ["romp*", "en", "mil", "pedazos"],
    ["romp*", "la", "baraja"],
    ["romp*", "la", "crisma"],
    ["romp*", "los", "esquemas"],
    ["romp*", "moldes"],
    ["romp*", "una", "lanza", "en", "favor", "de"],
    ["ronda", "la", "idea"],
    ["roz*", "la", "perfección"],
    ["rubia", "de", "bote"],
    ["ruido", "mediático"],
    ["ruido", "y", "pocas", "nueces"],
    ["rumor", "extendido"],
    ["rápido", "desenlace"],
    ["récord", "de", "participación"],
    ["s*", "en", "el", "alma"],
    ["s*", "tambores", "de", "guerra"],
    ["sab*", "a", "rayos"],
    ["sab*", "de", "buena", "tinta"],
    ["sab*", "de", "primera", "mano"],
    ["sab*", "de", "qué", "pie", "cojea"],
    ["sab*", "lo", "que", "no", "está", "escrito"],
    ["sab*", "más", "que", "lepe"],
    ["sab*", "más", "que", "los", "ratones", "colorados"],
    ["sab*", "por", "dónde", "van", "los", "tiros"],
    ["sab*", "que", "es", "bueno"],
    ["sabore*", "el", "triunfo"],
    ["sac*", "a", "colación"],
    ["sac*", "a", "la", "palestra"],
    ["sac*", "con", "sacacorchos"],
    ["sac*", "de", "debajo", "de", "las", "piedras"],
    ["sac*", "de", "la", "manga"],
    ["sac*", "de", "madre"],
    ["sac*", "de", "pobre"],
    ["sac*", "de", "quicio"],
    ["sac*", "de", "sus", "casillas"],
    ["sac*", "los", "colores"],
    ["sac*", "los", "pies", "del", "tiesto"],
    ["sac*", "partido"],
    ["sac*", "pecho"],
    ["sac*", "su", "lado", "más"],
    ["sac*", "tajada"],
    ["sac*", "un", "as", "de", "la", "manga"],
    ["sac*", "un", "conejo", "de", "la", "chistera"],
    ["sac*", "una", "espinita"],
    ["sal", "de", "todos", "los", "platos"],
    ["sal*", "a", "flote"],
    ["sal*", "a", "la", "luz"],
    ["sal*", "al", "ruedo"],
    ["sal*", "como", "churros"],
    ["sal*", "como", "setas"],
    ["sal*", "con", "la", "suya"],
    ["sal*", "con", "los", "pies", "por", "delante"],
    ["sal*", "de", "fábrica"],
    ["sal*", "de", "la", "cueva"],
    ["sal*", "de", "la", "zona", "de", "confort"],
    ["sal*", "de", "madre"],
    ["sal*", "de", "pobre"],
    ["sal*", "del", "armario"],
    ["sal*", "del", "atolladero"],
    ["sal*", "del", "cascarón"],
    ["sal*", "del", "nido"],
    ["sal*", "del", "paso"],
    ["sal*", "el", "tiro", "por", "la", "culata"],
    ["sal*", "pitando"],
    ["sal*", "por", "la", "tangente"],
    ["sal*", "por", "piernas"],
    ["sal*", "rana"],
    ["sal*", "todo", "redondo"],
    ["sald*", "una", "deuda", "pendiente"],
    ["salga", "el", "sol", "por", "antequera"],
    ["salida", "de", "tono"],
    ["salt*", "a", "la", "fama"],
    ["salt*", "a", "la", "vista"],
    ["salt*", "al", "terreno", "de", "juego"],
    ["salt*", "al", "vacío"],
    ["salt*", "chispas"],
    ["salt*", "de", "alegría"],
    ["salt*", "la", "liebre"],
    ["saludo", "cordial"],
    ["salv*", "los", "muebles"],
    ["salv*", "un", "escollo"],
    ["sane*", "las", "cuentas"],
    ["sangre", "de", "horchata"],
    ["sangre", "no", "llegó", "al", "río"],
    ["santa", "rita", "rita", "lo", "que", "da", "no", "se", "quita"],
    ["santo", "de", "mi", "devoción"],
    ["se", "[lt]e", "ve", "el", "plumero"],
    ["se", "acabó", "lo", "que", "se", "daba"],
    ["se", "cae", "de", "la", "convocatoria"],
    ["se", "debat*", "entre", "la", "vida", "y", "la", "muerte"],
    ["se", "desat*", "la", "polémica"],
    ["se", "di*", "a", "la", "fuga"],
    ["se", "dice", "pronto"],
    ["se", "fu*", "apagando", "lentamente"],
    ["se", "fu*", "de", "gira"],
    ["se", "fundieron", "en", "un", "abrazo"],
    ["se", "h*", "desarrollado", "con", "normalidad"],
    ["se", "hace", "camino", "al", "andar"],
    ["se", "l*", "fue", "de", "las", "manos"],
    ["se", "l*", "pasa", "el", "arroz"],
    ["se", "me", "está", "acabando", "la", "paciencia"],
    ["se", "mueve", "mucho"],
    ["se", "puede", "decir", "más", "alto", "pero", "no", "más", "claro"],
    ["se", "puso", "sobre", "la", "mesa"],
    ["se", "respira", "un", "gran", "ambiente"],
    ["seco", "que", "la", "mojama"],
    ["secreto", "a", "voces"],
    ["sed", "de", "justicia"],
    ["sed", "de", "venganza"],
    ["seg*", "la", "vida"],
    ["segu*", "en", "sus", "trece"],
    ["segu*", "la", "corriente"],
    ["seguiremos", "atentos", "a", "esta", "información"],
    ["segundas", "partes", "fueron", "buenas"],
    ["según", "el", "color", "del", "cristal", "con", "que", "se", "mira"],
    ["según", "las", "primeras", "hipótesis"],
    ["sell*", "sus", "labios"],
    ["sembr*", "cizaña"],
    ["sembr*", "la", "discordia"],
    ["sent*", "a", "cuerno", "quemado"],
    ["sent*", "a", "sus", "anchas"],
    ["sent*", "cabeza"],
    ["sent*", "como", "pez", "en", "el", "agua"],
    ["sent*", "como", "un", "guante"],
    ["sent*", "como", "un", "tiro"],
    ["sent*", "como", "una", "patada"],
    ["sent*", "cátedra"],
    ["sent*", "de", "perlas"],
    ["sent*", "las", "bases"],
    ["sentencia", "de", "muerte"],
    ["sentido", "homenaje"],
    ["sentido", "pésame"],
    ["separ*", "la", "paja", "del", "trigo"],
    ["sepulcro", "blanqueado"],
    ["serio", "candidato"],
    ["servir", "en", "bandeja"],
    ["severo", "correctivo"],
    ["si", "encarta"],
    ["si", "eres", "más", "tonto", "no", "naces"],
    ["si", "quieres", "las", "tomas", "y", "si", "no", "las", "dejas"],
    ["si", "suena", "la", "flauta"],
    ["si", "te", "he", "visto", "no", "me", "acuerdo"],
    ["siempre", "hay", "un", "roto", "para", "un", "descosido"],
    ["silencio", "atronador"],
    ["sin", "comerlo", "ni", "beberlo"],
    ["sin", "entrar", "en", "detalles"],
    ["sin", "lugar", "a", "dudas"],
    ["sin", "mediar", "palabra"],
    ["sin", "más", "dilación"],
    ["sin", "más", "preámbulos"],
    ["sin", "ningún", "género", "de", "dudas"],
    ["sin", "pena", "ni", "gloria"],
    ["sin", "pies", "ni", "cabeza"],
    ["sin", "prisa", "pero", "sin", "pausa"],
    ["sin", "ton", "ni", "son"],
    ["sin", "trampa", "ni", "cartón"],
    ["sincero", "pero", "emotivo"],
    ["singladura", "política"],
    ["situación", "insostenible"],
    ["situación", "límite"],
    ["sobre", "ruedas"],
    ["sol", "de", "justicia"],
    ["sol", "radiante"],
    ["solo", "ante", "el", "peligro"],
    ["solo", "el", "cielo", "lo", "sabe"],
    ["solo", "la", "punta", "del", "iceberg"],
    ["solo", "que", "la", "una"],
    ["solt*", "amarras"],
    ["solt*", "el", "pelo"],
    ["solt*", "el", "rollo"],
    ["solt*", "la", "melena"],
    ["solt*", "la", "mosca"],
    ["solt*", "la", "pasta"],
    ["solt*", "lastre"],
    ["solt*", "un", "bombazo"],
    ["solt*", "una", "parrafada"],
    ["soltero", "de", "oro"],
    ["solucion*", "la", "papeleta"],
    ["son", "habas", "contadas"],
    ["son", "palabras", "mayores"],
    ["son*", "a", "chino"],
    ["son*", "a", "música", "celestial"],
    ["sonreí*", "la", "vida"],
    ["sonrisa", "en", "los", "labios"],
    ["sordo", "como", "una", "tapia"],
    ["sorte*", "todo", "tipo", "de", "obstáculos"],
    ["soñ*", "despierto"],
    ["su", "mínima", "expresión"],
    ["sub*", "a", "la", "cabeza"],
    ["sub*", "a", "la", "chepa"],
    ["sub*", "a", "la", "parra"],
    ["sub*", "a", "las", "barbas"],
    ["sub*", "al", "carro"],
    ["sub*", "como", "la", "espuma"],
    ["sub*", "de", "tono"],
    ["sub*", "el", "listón"],
    ["sub*", "enteros"],
    ["sub*", "los", "humos"],
    ["sub*", "por", "las", "paredes"],
    ["sucio", "que", "el", "palo", "de", "un", "gallinero"],
    ["sud*", "a", "mares"],
    ["sud*", "como", "un", "cerdo"],
    ["sud*", "como", "un", "pollo"],
    ["sud*", "la", "camiseta"],
    ["sud*", "la", "gota", "gorda"],
    ["sud*", "sangre"],
    ["sud*", "tinta", "china"],
    ["suerte", "está", "echada"],
    ["suerte", "suprema"],
    ["suerte", "va", "por", "barrios"],
    ["suerte", "vista", "y", "al", "toro"],
    ["sueño", "dorado"],
    ["sueño", "reparador"],
    ["sufr*", "en", "sus", "propias", "carnes"],
    ["sufr*", "lo", "indecible"],
    ["sufr*", "un", "calvario"],
    ["sufr*", "un", "revés"],
    ["sufr*", "un", "varapalo"],
    ["suma", "y", "sigue"],
    ["sus", "mejores", "galas"],
    ["sálvese", "quien", "pueda"],
    ["sí", "ni", "no", "sino", "todo", "lo", "contrario"],
    ["sí", "o", "sí"],
    ["sólo", "el", "tiempo", "lo", "dirá"],
    ["tabla", "de", "salvación"],
    ["tal", "día", "como", "hoy"],
    ["taladrar", "con", "la", "mirada"],
    ["talón", "de", "aquiles"],
    ["tampoco", "*", "para", "tanto"],
    ["tan", "fiero", "el", "león", "como", "lo", "pintan"],
    ["tanto", "monta", "monta", "tanto"],
    ["tanto", "ni", "tan", "calvo"],
    ["tanto", "va", "el", "cántaro", "a", "la", "fuente"],
    ["tararí", "que", "te", "vi"],
    ["tard*", "una", "eternidad"],
    ["tarde", "o", "temprano"],
    ["te", "conozco", "bacalao", "aunque", "vengas", "disfrazado"],
    ["te", "quiero", "como", "la", "trucha", "al", "trucho"],
    ["teatro", "de", "operaciones"],
    ["tecnología", "punta"],
    ["tejemaneje"],
    ["tejido", "social"],
    ["tela", "marinera"],
    ["tela", "que", "cortar"],
    ["tem*", "lo", "peor"],
    ["tema", "candente"],
    ["tembl*", "las", "piernas"],
    ["templ*", "gaitas"],
    ["temporada", "estival"],
    ["ten*", "a", "huevo"],
    ["ten*", "agallas"],
    ["ten*", "altura", "de", "miras"],
    ["ten*", "atravesado"],
    ["ten*", "bemoles"],
    ["ten*", "buen", "estómago"],
    ["ten*", "buen", "fondo"],
    ["ten*", "buen", "ojo"],
    ["ten*", "buen", "oído"],
    ["ten*", "buen", "pico"],
    ["ten*", "buen", "rollo"],
    ["ten*", "buen", "saque"],
    ["ten*", "buena", "boca"],
    ["ten*", "buena", "mano"],
    ["ten*", "buena", "percha"],
    ["ten*", "buena", "pinta"],
    ["ten*", "buenas", "vibraciones"],
    ["ten*", "calado"],
    ["ten*", "cartucheras"],
    ["ten*", "claro"],
    ["ten*", "crudo"],
    ["ten*", "en", "el", "bote"],
    ["ten*", "en", "la", "recámara"],
    ["ten*", "en", "un", "pedestal"],
    ["ten*", "enchufe"],
    ["ten*", "fecha", "de", "caducidad"],
    ["ten*", "la", "lengua", "afilada"],
    ["ten*", "la", "lengua", "muy", "larga"],
    ["ten*", "la", "mano", "muy", "larga"],
    ["ten*", "la", "negra"],
    ["ten*", "la", "vida", "resuelta"],
    ["ten*", "la", "última", "palabra"],
    ["ten*", "las", "manos", "atadas"],
    ["ten*", "las", "manos", "de", "mantequilla"],
    ["ten*", "las", "manos", "largas"],
    ["ten*", "las", "manos", "manchadas", "de", "sangre"],
    ["ten*", "las", "pilas", "cargadas"],
    ["ten*", "lo", "que", "hay", "que", "tener"],
    ["ten*", "los", "pies", "en", "el", "suelo"],
    ["ten*", "los", "pies", "en", "la", "tierra"],
    ["ten*", "mala", "leche"],
    ["ten*", "mala", "uva"],
    ["ten*", "malas", "pulgas"],
    ["ten*", "manga", "ancha"],
    ["ten*", "mano", "de", "santo"],
    ["ten*", "que", "pringar"],
    ["ten*", "sangre", "azul"],
    ["ten*", "sangre", "fría"],
    ["ten*", "siete", "ojos"],
    ["ten*", "siete", "vidas"],
    ["ten*", "su", "aquel"],
    ["ten*", "su", "intríngulis"],
    ["ten*", "sus", "más", "y", "sus", "menos"],
    ["ten*", "tablas"],
    ["ten*", "tirria"],
    ["ten*", "todas", "las", "papeletas"],
    ["ten*", "todo", "el", "tiempo", "del", "mundo"],
    ["ten*", "un", "as", "bajo", "la", "manga"],
    ["ten*", "un", "as", "en", "la", "manga"],
    ["ten*", "un", "catarro", "de", "aúpa"],
    ["ten*", "un", "cerebro", "de", "mosquito"],
    ["ten*", "un", "colchón"],
    ["ten*", "un", "corazón", "que", "no", "le", "cabe", "en", "el", "pecho"],
    ["ten*", "un", "cuerpo", "diez"],
    ["ten*", "un", "enganche"],
    ["ten*", "un", "flechazo"],
    ["ten*", "un", "fondo", "de", "reptiles"],
    ["ten*", "un", "morro", "que", "se", "lo", "pisa"],
    ["ten*", "un", "nudo", "en", "el", "estómago"],
    ["ten*", "un", "nudo", "en", "la", "garganta"],
    ["ten*", "un", "ojo", "a", "la", "virulé"],
    ["ten*", "un", "oído", "enfrente", "del", "otro"],
    ["ten*", "un", "padrino"],
    ["ten*", "un", "pico", "de", "oro"],
    ["ten*", "un", "pie", "dentro", "y", "otro", "fuera"],
    ["ten*", "un", "pie", "en", "el", "aire"],
    ["ten*", "un", "pie", "en", "el", "hoyo"],
    ["ten*", "un", "pie", "en", "la", "final"],
    ["ten*", "un", "plan", "b"],
    ["ten*", "un", "rifirrafe"],
    ["ten*", "un", "rollo", "de", "verano"],
    ["ten*", "un", "subidón"],
    ["ten*", "un", "tomate", "en", "el", "calcetín"],
    ["ten*", "una", "agenda", "muy", "apretada"],
    ["ten*", "una", "bola", "de", "cristal"],
    ["ten*", "una", "empanada", "mental"],
    ["ten*", "una", "espinita", "clavada"],
    ["ten*", "una", "memoria", "de", "elefante"],
    ["ten*", "una", "pedrada"],
    ["ten*", "una", "salud", "de", "hierro"],
    ["tend*", "la", "mano"],
    ["tend*", "puentes"],
    ["tensa", "calma"],
    ["tensión", "en", "el", "ambiente"],
    ["tentar", "a", "la", "suerte"],
    ["terco", "que", "una", "mula"],
    ["terreno", "abonado"],
    ["terrible", "desastre"],
    ["tiempo", "inclemente"],
    ["tiempos", "convulsos"],
    ["tierra", "de", "por", "medio"],
    ["tieso", "que", "un", "junco"],
    ["tir*", "a", "matar"],
    ["tir*", "con", "pólvora", "de", "rey"],
    ["tir*", "de", "hemeroteca"],
    ["tir*", "de", "ingenio"],
    ["tir*", "de", "la", "lengua"],
    ["tir*", "de", "la", "manta"],
    ["tir*", "de", "los", "pelos"],
    ["tir*", "de", "oficio"],
    ["tir*", "del", "carro"],
    ["tir*", "la", "casa", "por", "la", "ventana"],
    ["tir*", "la", "piedra", "y", "esconder", "la", "mano"],
    ["tir*", "la", "toalla"],
    ["tir*", "los", "tejos"],
    ["tir*", "los", "trastos", "a", "la", "cabeza"],
    ["tir*", "por", "la", "borda"],
    ["tir*", "por", "la", "calle", "de", "en", "medio"],
    ["tir*", "todo", "por", "la", "borda"],
    ["tira", "y", "afloja"],
    ["tirado", "que", "una", "colilla"],
    ["tiritar", "de", "frío"],
    ["to[cq]*", "la", "moral"],
    ["toc*", "a", "rebato"],
    ["toc*", "el", "cielo", "con", "las", "manos"],
    ["toc*", "el", "gordo"],
    ["toc*", "fondo"],
    ["toc*", "la", "china"],
    ["toc*", "la", "fibra", "sensible"],
    ["toc*", "los", "huevos"],
    ["toc*", "madera"],
    ["toc*", "un", "buen", "pellizco"],
    ["tocado", "y", "hundido"],
    ["toda", "ayuda", "es", "poca"],
    ["todo", "a", "una", "carta"],
    ["todo", "atado", "y", "bien", "atado"],
    ["todo", "bajo", "control"],
    ["todo", "cristo"],
    ["todo", "dios"],
    ["todo", "el", "monte", "es", "orégano"],
    ["todo", "el", "pescado", "vendido"],
    ["todo", "el", "santo", "día"],
    ["todo", "lo", "que", "es"],
    ["todo", "oídos"],
    ["todo", "pasa", "por", "algo"],
    ["todo", "patas", "arriba"],
    ["todo", "se", "andará"],
    ["todo", "un", "caballero"],
    ["todo", "un", "ejemplo", "de", "superación"],
    ["todos", "a", "una"],
    ["todos", "los", "huevos", "en", "la", "misma", "cesta"],
    ["todos", "los", "indicios", "apuntan"],
    ["todos", "los", "tontos", "tienen", "suerte"],
    ["tolerancia", "cero"],
    ["tom*", "a", "cachondeo"],
    ["tom*", "a", "la", "tremenda"],
    ["tom*", "a", "pecho"],
    ["tom*", "a", "risa"],
    ["tom*", "buena", "nota"],
    ["tom*", "el", "pelo"],
    ["tom*", "el", "pulso", "a", "la", "calle"],
    ["tom*", "las", "de", "villadiego"],
    ["tom*", "su", "tiempo"],
    ["toma", "y", "daca"],
    ["tontas", "y", "a", "locas"],
    ["tonterías", "las", "justas"],
    ["tonto", "de", "capirote"],
    ["tonto", "de", "remate"],
    ["tonto", "del", "bote"],
    ["tonto", "del", "haba"],
    ["tonto", "perdido"],
    ["tonto", "que", "abundio"],
    ["tonto", "que", "el", "que", "asó", "la", "manteca"],
    ["tormenta", "perfecta"],
    ["tormentas", "puntuales"],
    ["toros", "desde", "la", "barrera"],
    ["torpedo", "contra", "la", "línea", "de", "flotación"],
    ["torres", "más", "altas", "han", "caído"],
    ["total", "hermetismo"],
    ["tra*", "de", "cabeza"],
    ["tra*", "por", "la", "calle", "de", "la", "amargura"],
    ["tra*", "por", "los", "pelos"],
    ["tra*", "sin", "cuidado"],
    ["trabaj*", "como", "un", "animal"],
    ["trabaj*", "como", "un", "chino"],
    ["trabaj*", "como", "un", "negro"],
    ["trabaj*", "en", "la", "sombra"],
    ["trabajo", "de", "chinos"],
    ["tradición", "muy", "arraigada"],
    ["trae", "sin", "cuidado"],
    ["trag*", "las", "palabras"],
    ["trag*", "una", "trola"],
    ["tragar", "sapos", "y", "culebras"],
    ["tragedia", "de", "grandes", "proporciones"],
    ["trancas", "y", "barrancas"],
    ["transmisión", "ininterrumpida"],
    ["traslad*", "la", "decisión"],
    ["traz*", "un", "plan", "al", "milímetro"],
    ["tremendo", "zambombazo"],
    ["tres", "en", "un", "burro"],
    ["triste", "desenlace"],
    ["triunfo", "agridulce"],
    ["troche", "y", "moche"],
    ["troncharse", "de", "risa"],
    ["tráfico", "de", "influencias"],
    ["trágico", "accidente"],
    ["tu", "cara", "me", "suena"],
    ["tumb*", "a", "la", "bartola"],
    ["tumb*", "la", "resolución"],
    ["tímido", "aplauso"],
    ["tío", "legal"],
    ["títere", "con", "cabeza"],
    ["tónica", "general"],
    ["tú", "mismo", "con", "tu", "mecanismo"],
    ["un", "agonías"],
    ["un", "aguafiestas"],
    ["un", "antes", "y", "un", "después"],
    ["un", "bala"],
    ["un", "besugo"],
    ["un", "bicho", "raro"],
    ["un", "borde"],
    ["un", "buen", "número"],
    ["un", "cabra", "loca"],
    ["un", "cacho", "de", "pan"],
    ["un", "cagaprisas"],
    ["un", "callo"],
    ["un", "calzonazos"],
    ["un", "camino", "de", "rosas"],
    ["un", "cantamañanas"],
    ["un", "caradura"],
    ["un", "caso", "perdido"],
    ["un", "cenizo"],
    ["un", "chanchullo"],
    ["un", "chaquetero"],
    ["un", "chupóptero"],
    ["un", "cielo"],
    ["un", "cocinillas"],
    ["un", "crack"],
    ["un", "día", "como", "hoy", "hace", "ya"],
    ["un", "día", "es", "un", "día"],
    ["un", "efecto", "dominó"],
    ["un", "escalofrío", "por", "todo", "el", "cuerpo"],
    ["un", "fantasma"],
    ["un", "fenómeno"],
    ["un", "fiera"],
    ["un", "fittipaldi"],
    ["un", "gallina"],
    ["un", "gol", "por", "toda", "la", "escuadra"],
    ["un", "gorrón"],
    ["un", "grano", "en", "el", "culo"],
    ["un", "hacha"],
    ["un", "lastre"],
    ["un", "libro", "abierto"],
    ["un", "mar", "de", "dudas"],
    ["un", "pajarito", "me", "ha", "dicho"],
    ["un", "papel", "a", "la", "perfección"],
    ["un", "pelo", "de", "tonto"],
    ["un", "santo", "para", "desvestir", "a", "otro"],
    ["un", "tiro", "en", "el", "pie"],
    ["un", "viva", "la", "virgen"],
    ["una", "comedura", "de", "coco"],
    ["una", "copa", "de", "más"],
    ["una", "doble", "vida"],
    ["una", "mancha", "en", "su", "trayectoria"],
    ["una", "pica", "en", "flandes"],
    ["una", "vela", "a", "dios", "y", "otra", "al", "diablo"],
    ["una", "y", "no", "más", "santo", "tomás"],
    ["unión", "hace", "la", "fuerza"],
    ["unos", "tortolitos"],
    ["v*", "más", "allá", "de", "*", "narices"],
    ["v[ei]n*", "con", "cuentos"],
    ["va", "a", "pillar", "el", "toro"],
    ["va", "a", "ser", "que", "no"],
    ["va", "a", "ser", "que", "sí"],
    ["va", "a", "ser", "un", "bombazo"],
    ["va", "que", "chuta"],
    ["vaca", "lechera"],
    ["vago", "redomado"],
    ["val*", "la", "pena"],
    ["val*", "su", "peso", "en", "oro"],
    ["val*", "un", "potosí"],
    ["vale", "tarde", "que", "nunca"],
    ["valga", "la", "redundancia"],
    ["valor*", "positivamente"],
    ["vaso", "medio", "lleno"],
    ["vaya", "pieza"],
    ["vaya", "tela"],
    ["vaya", "usted", "con", "dios"],
    ["ve*", "las", "caras"],
    ["vela", "en", "este", "entierro"],
    ["vello", "de", "punta"],
    ["velocidad", "de", "crucero"],
    ["veloz", "como", "un", "rayo"],
    ["veloz", "como", "una", "centella"],
    ["vemos", "abocados", "a"],
    ["ven*", "al", "mundo"],
    ["ven*", "al", "pelo"],
    ["ven*", "como", "anillo", "al", "dedo"],
    ["ven*", "con", "el", "mismo", "cuento", "de", "siempre"],
    ["ven*", "con", "la", "cabeza", "gacha"],
    ["ven*", "con", "la", "misma", "cantinela"],
    ["ven*", "de", "miedo"],
    ["ven*", "de", "perlas"],
    ["ven*", "para", "quedarse"],
    ["ven*", "que", "ni", "pintado"],
    ["vend*", "cara", "la", "derrota"],
    ["vend*", "como", "churros"],
    ["vend*", "como", "rosquillas"],
    ["vend*", "hielo", "a", "un", "esquimal"],
    ["vend*", "humo"],
    ["vend*", "la", "burra"],
    ["vend*", "la", "moto"],
    ["vend*", "la", "piel", "del", "oso", "antes", "de", "cazarlo"],
    ["vend*", "su", "alma", "al", "diablo"],
    ["ver", "para", "creer"],
    ["ver*", "ni", "en", "pintura"],
    ["verdad", "es", "que"],
    ["verdadera", "encuesta", "son", "las", "elecciones"],
    ["verdadera", "encuesta", "son", "las", "urnas"],
    ["verdadero", "infierno"],
    ["verdades", "como", "puños"],
    ["vergüenza", "ajena"],
    ["vergüenza", "torera"],
    ["verlas", "venir"],
    ["verter", "lágrimas"],
    ["vete", "tú", "a", "saber"],
    ["viaje", "al", "centro", "de"],
    ["victoria", "agridulce"],
    ["victoria", "pírrica"],
    ["victoria", "sin", "paliativos"],
    ["vida", "da", "muchas", "vueltas"],
    ["vida", "de", "perros"],
    ["vida", "es", "una", "tómbola"],
    ["vidas", "paralelas"],
    ["viejas", "rencillas"],
    ["viejo", "zorro"],
    ["viento", "en", "popa"],
    ["vino", "dios", "a", "ver"],
    ["violento", "choque"],
    ["virgencita", "que", "me", "quede", "como", "estoy"],
    ["virtual", "empate"],
    ["visiblemente", "afectado"],
    ["visto", "lo", "visto"],
    ["vital", "elemento"],
    ["viv*", "como", "dios"],
    ["viv*", "como", "un", "cura"],
    ["viv*", "como", "un", "marqués"],
    ["viv*", "como", "una", "reina"],
    ["viv*", "con", "lo", "puesto"],
    ["viv*", "de", "ilusiones"],
    ["viv*", "de", "la", "sopa", "boba"],
    ["viv*", "de", "las", "rentas"],
    ["viv*", "del", "cuento"],
    ["viv*", "en", "su", "mundo"],
    ["viv*", "en", "una", "burbuja"],
    ["viv*", "una", "auténtica", "pesadilla"],
    ["viv*", "una", "segunda", "juventud"],
    ["vivir", "que", "son", "dos", "días"],
    ["volar", "todos", "los", "puentes"],
    ["volc*", "con", "algo"],
    ["volv*", "a", "la", "carga"],
    ["volv*", "a", "la", "normalidad"],
    ["volv*", "a", "las", "andadas"],
    ["volv*", "a", "nacer"],
    ["volv*", "al", "redil"],
    ["volv*", "la", "espalda"],
    ["volv*", "la", "vista", "atrás"],
    ["volv*", "loco"],
    ["volv*", "majara"],
    ["volv*", "tarumba"],
    ["voraz", "incendio"],
    ["voy", "a", "explotar"],
    ["vuelco", "en", "el", "caso"],
    ["vuelta", "de", "hoja"],
    ["vuelta", "de", "tuerca"],
    ["váyase", "al", "carajo"],
    ["vérselas", "y", "deseárselas"],
    ["víctima", "de", "su", "propio", "éxito"],
    ["y", "punto", "pelota"],
    ["y", "punto"],
    ["y", "qué", "más", "podemos", "añadir"],
    ["y", "sanseacabó"],
    ["y", "si", "no", "al", "tiempo"],
    ["y", "tal", "y", "cual"],
    ["y", "vuelta", "y", "dale"],
    ["y", "yo", "con", "estos", "pelos"],
    ["ya", "no", "está", "entre", "nosotros"],
    ["ya", "no", "los", "cumple"],
    ["ya", "si", "eso", "voy"],
    ["ya", "te", "vale"],
    ["ya", "vendrán", "tiempos", "mejores"],
    ["zas", "en", "toda", "la", "boca"],
    ["zona", "cero"],
    ["zona", "menos", "favorecida"],
    ["zorro", "a", "guardar", "gallinas"],
    ["zurr*", "la", "badana"],
    ["árboles", "no", "dejan", "ver", "el", "bosque"],
    ["échale", "hilo", "a", "la", "cometa"],
    ["época", "de", "vacas", "flacas"],
    ["éramos", "pocos", "y", "parió", "la", "abuela"],
    ["éxodo", "masivo"],
    ["ídem", "de", "lienzo"],
    ["ídolo", "de", "masas"],
    ["última", "corre", "de", "mi", "cuenta"],
    ["último", "cartucho"],
)

for e in _CLICHE_EXPR:
    e.reverse()

_CLICHE_EXPR_DICT: Dict[str, Tuple[List[str], ...]] = {}

for expr in _CLICHE_EXPR:
    key_letters = expr[0][:_CLICHE_EXPR_DICT_KEYLEN]

    if key_letters not in _CLICHE_EXPR_DICT:
        _CLICHE_EXPR_DICT[key_letters] = [expr]
    else:
        _CLICHE_EXPR_DICT[key_letters].append(expr)


def get_fistword_exprs(word) -> Optional[List[List[str]]]:
    return _CLICHE_EXPR_DICT.get(word[:_CLICHE_EXPR_DICT_KEYLEN])
